# Autogenerated by nbdev

d = { 'settings': { 'audience': 'Developers',
                'author': 'Jeremy Howard, Sylvain Gugger, and contributors',
                'author_email': 'info@fast.ai',
                'branch': 'master',
                'conda_requirements': 'pytorch>=1.7,<1.14',
                'console_scripts': 'configure_accelerate=fastai.distributed:configure_accelerate',
                'copyright': 'fast.ai',
                'custom_sidebar': 'True',
                'description': 'fastai simplifies training fast and accurate neural nets using modern best practices',
                'dev_requirements': 'ipywidgets pytorch-lightning pytorch-ignite transformers sentencepiece tensorboard pydicom catalyst flask_compress '
                                    'captum>=0.3 flask wandb kornia scikit-image neptune-client comet_ml albumentations opencv-python pyarrow catalyst ninja '
                                    'timm>=0.6.2.dev accelerate>=0.10.0',
                'doc_baseurl': '/',
                'doc_host': 'https://docs.fast.ai',
                'doc_path': '_docs',
                'git_url': 'https://github.com/fastai/fastai/tree/master/',
                'host': 'github',
                'keywords': 'fastai, deep learning, machine learning',
                'language': 'English',
                'lib_name': 'fastai',
                'lib_path': 'fastai',
                'license': 'apache2',
                'min_python': '3.7',
                'nbs_path': 'nbs',
                'pip_requirements': 'torch>=1.7,<1.14',
                'recursive': 'True',
                'requirements': 'fastdownload>=0.0.5,<2 fastcore>=1.4.5,<1.6 torchvision>=0.8.2 matplotlib pandas requests pyyaml fastprogress>=0.2.4 '
                                'pillow>6.0.0 scikit-learn scipy spacy<4 packaging',
                'status': '4',
                'title': 'fastai',
                'tst_flags': 'slow cpp cuda multicuda',
                'user': 'fastai',
                'version': '2.7.9'},
  'syms': { 'fastai.basics': {},
            'fastai.callback.all': {},
            'fastai.callback.azureml': { 'fastai.callback.azureml.AzureMLCallback': 'https://docs.fast.ai/callback.azureml.html#azuremlcallback',
                                         'fastai.callback.azureml.AzureMLCallback.after_batch': 'https://docs.fast.ai/callback.azureml.html#azuremlcallback.after_batch',
                                         'fastai.callback.azureml.AzureMLCallback.after_epoch': 'https://docs.fast.ai/callback.azureml.html#azuremlcallback.after_epoch',
                                         'fastai.callback.azureml.AzureMLCallback.before_fit': 'https://docs.fast.ai/callback.azureml.html#azuremlcallback.before_fit'},
            'fastai.callback.captum': { 'fastai.callback.captum.CaptumInterpretation': 'https://docs.fast.ai/callback.captum.html#captuminterpretation',
                                        'fastai.callback.captum.CaptumInterpretation.get_baseline_img': 'https://docs.fast.ai/callback.captum.html#captuminterpretation.get_baseline_img',
                                        'fastai.callback.captum.CaptumInterpretation.insights': 'https://docs.fast.ai/callback.captum.html#captuminterpretation.insights',
                                        'fastai.callback.captum.CaptumInterpretation.visualize': 'https://docs.fast.ai/callback.captum.html#captuminterpretation.visualize'},
            'fastai.callback.comet': { 'fastai.callback.comet.CometCallback': 'https://docs.fast.ai/callback.comet.html#cometcallback',
                                       'fastai.callback.comet.CometCallback.after_batch': 'https://docs.fast.ai/callback.comet.html#cometcallback.after_batch',
                                       'fastai.callback.comet.CometCallback.after_epoch': 'https://docs.fast.ai/callback.comet.html#cometcallback.after_epoch',
                                       'fastai.callback.comet.CometCallback.after_fit': 'https://docs.fast.ai/callback.comet.html#cometcallback.after_fit',
                                       'fastai.callback.comet.CometCallback.before_fit': 'https://docs.fast.ai/callback.comet.html#cometcallback.before_fit'},
            'fastai.callback.core': { 'fastai.callback.core.Callback': 'https://docs.fast.ai/callback.core.html#callback',
                                      'fastai.callback.core.Callback.name': 'https://docs.fast.ai/callback.core.html#callback.name',
                                      'fastai.callback.core.CancelBackwardException': 'https://docs.fast.ai/callback.core.html#cancelbackwardexception',
                                      'fastai.callback.core.CancelBatchException': 'https://docs.fast.ai/callback.core.html#cancelbatchexception',
                                      'fastai.callback.core.CancelEpochException': 'https://docs.fast.ai/callback.core.html#cancelepochexception',
                                      'fastai.callback.core.CancelFitException': 'https://docs.fast.ai/callback.core.html#cancelfitexception',
                                      'fastai.callback.core.CancelStepException': 'https://docs.fast.ai/callback.core.html#cancelstepexception',
                                      'fastai.callback.core.CancelTrainException': 'https://docs.fast.ai/callback.core.html#canceltrainexception',
                                      'fastai.callback.core.CancelValidException': 'https://docs.fast.ai/callback.core.html#cancelvalidexception',
                                      'fastai.callback.core.FetchPredsCallback': 'https://docs.fast.ai/callback.core.html#fetchpredscallback',
                                      'fastai.callback.core.FetchPredsCallback.after_validate': 'https://docs.fast.ai/callback.core.html#fetchpredscallback.after_validate',
                                      'fastai.callback.core.GatherPredsCallback': 'https://docs.fast.ai/callback.core.html#gatherpredscallback',
                                      'fastai.callback.core.GatherPredsCallback.after_batch': 'https://docs.fast.ai/callback.core.html#gatherpredscallback.after_batch',
                                      'fastai.callback.core.GatherPredsCallback.after_validate': 'https://docs.fast.ai/callback.core.html#gatherpredscallback.after_validate',
                                      'fastai.callback.core.GatherPredsCallback.all_tensors': 'https://docs.fast.ai/callback.core.html#gatherpredscallback.all_tensors',
                                      'fastai.callback.core.GatherPredsCallback.before_batch': 'https://docs.fast.ai/callback.core.html#gatherpredscallback.before_batch',
                                      'fastai.callback.core.GatherPredsCallback.before_validate': 'https://docs.fast.ai/callback.core.html#gatherpredscallback.before_validate',
                                      'fastai.callback.core.TrainEvalCallback': 'https://docs.fast.ai/callback.core.html#trainevalcallback',
                                      'fastai.callback.core.TrainEvalCallback.after_batch': 'https://docs.fast.ai/callback.core.html#trainevalcallback.after_batch',
                                      'fastai.callback.core.TrainEvalCallback.after_create': 'https://docs.fast.ai/callback.core.html#trainevalcallback.after_create',
                                      'fastai.callback.core.TrainEvalCallback.before_fit': 'https://docs.fast.ai/callback.core.html#trainevalcallback.before_fit',
                                      'fastai.callback.core.TrainEvalCallback.before_train': 'https://docs.fast.ai/callback.core.html#trainevalcallback.before_train',
                                      'fastai.callback.core.TrainEvalCallback.before_validate': 'https://docs.fast.ai/callback.core.html#trainevalcallback.before_validate',
                                      'fastai.callback.core.event': 'https://docs.fast.ai/callback.core.html#event'},
            'fastai.callback.data': { 'fastai.callback.data.CollectDataCallback': 'https://docs.fast.ai/callback.data.html#collectdatacallback',
                                      'fastai.callback.data.CollectDataCallback.after_batch': 'https://docs.fast.ai/callback.data.html#collectdatacallback.after_batch',
                                      'fastai.callback.data.CollectDataCallback.before_fit': 'https://docs.fast.ai/callback.data.html#collectdatacallback.before_fit',
                                      'fastai.callback.data.DataBlock.weighted_dataloaders': 'https://docs.fast.ai/callback.data.html#datablock.weighted_dataloaders',
                                      'fastai.callback.data.Datasets.weighted_dataloaders': 'https://docs.fast.ai/callback.data.html#datasets.weighted_dataloaders',
                                      'fastai.callback.data.FilteredBase.partial_dataloaders': 'https://docs.fast.ai/callback.data.html#filteredbase.partial_dataloaders',
                                      'fastai.callback.data.PartialDL': 'https://docs.fast.ai/callback.data.html#partialdl',
                                      'fastai.callback.data.PartialDL.get_idxs': 'https://docs.fast.ai/callback.data.html#partialdl.get_idxs',
                                      'fastai.callback.data.WeightedDL': 'https://docs.fast.ai/callback.data.html#weighteddl',
                                      'fastai.callback.data.WeightedDL.get_idxs': 'https://docs.fast.ai/callback.data.html#weighteddl.get_idxs'},
            'fastai.callback.fp16': { 'fastai.callback.fp16.FP16TestCallback': 'https://docs.fast.ai/callback.fp16.html#fp16testcallback',
                                      'fastai.callback.fp16.FP16TestCallback.after_pred': 'https://docs.fast.ai/callback.fp16.html#fp16testcallback.after_pred',
                                      'fastai.callback.fp16.Learner.to_fp16': 'https://docs.fast.ai/callback.fp16.html#learner.to_fp16',
                                      'fastai.callback.fp16.Learner.to_fp32': 'https://docs.fast.ai/callback.fp16.html#learner.to_fp32',
                                      'fastai.callback.fp16.Learner.to_non_native_fp16': 'https://docs.fast.ai/callback.fp16.html#learner.to_non_native_fp16',
                                      'fastai.callback.fp16.Learner.to_non_native_fp32': 'https://docs.fast.ai/callback.fp16.html#learner.to_non_native_fp32',
                                      'fastai.callback.fp16.MixedPrecision': 'https://docs.fast.ai/callback.fp16.html#mixedprecision',
                                      'fastai.callback.fp16.MixedPrecision.after_fit': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.after_fit',
                                      'fastai.callback.fp16.MixedPrecision.after_loss': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.after_loss',
                                      'fastai.callback.fp16.MixedPrecision.after_pred': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.after_pred',
                                      'fastai.callback.fp16.MixedPrecision.after_step': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.after_step',
                                      'fastai.callback.fp16.MixedPrecision.before_backward': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.before_backward',
                                      'fastai.callback.fp16.MixedPrecision.before_batch': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.before_batch',
                                      'fastai.callback.fp16.MixedPrecision.before_fit': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.before_fit',
                                      'fastai.callback.fp16.MixedPrecision.before_step': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.before_step',
                                      'fastai.callback.fp16.MixedPrecision.param_groups': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.param_groups',
                                      'fastai.callback.fp16.MixedPrecision.step': 'https://docs.fast.ai/callback.fp16.html#mixedprecision.step',
                                      'fastai.callback.fp16.ModelToHalf': 'https://docs.fast.ai/callback.fp16.html#modeltohalf',
                                      'fastai.callback.fp16.ModelToHalf.after_fit': 'https://docs.fast.ai/callback.fp16.html#modeltohalf.after_fit',
                                      'fastai.callback.fp16.ModelToHalf.before_fit': 'https://docs.fast.ai/callback.fp16.html#modeltohalf.before_fit',
                                      'fastai.callback.fp16.NonNativeMixedPrecision': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.after_batch': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.after_batch',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.after_fit': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.after_fit',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.after_pred': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.after_pred',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.after_step': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.after_step',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.before_backward': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.before_backward',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.before_batch': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.before_batch',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.before_fit': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.before_fit',
                                      'fastai.callback.fp16.NonNativeMixedPrecision.before_step': 'https://docs.fast.ai/callback.fp16.html#nonnativemixedprecision.before_step',
                                      'fastai.callback.fp16.copy_clone': 'https://docs.fast.ai/callback.fp16.html#copy_clone',
                                      'fastai.callback.fp16.get_master': 'https://docs.fast.ai/callback.fp16.html#get_master',
                                      'fastai.callback.fp16.grad_overflow': 'https://docs.fast.ai/callback.fp16.html#grad_overflow',
                                      'fastai.callback.fp16.test_overflow': 'https://docs.fast.ai/callback.fp16.html#test_overflow',
                                      'fastai.callback.fp16.to_master_grads': 'https://docs.fast.ai/callback.fp16.html#to_master_grads',
                                      'fastai.callback.fp16.to_model_params': 'https://docs.fast.ai/callback.fp16.html#to_model_params'},
            'fastai.callback.hook': { 'fastai.callback.hook.ActivationStats': 'https://docs.fast.ai/callback.hook.html#activationstats',
                                      'fastai.callback.hook.ActivationStats.after_batch': 'https://docs.fast.ai/callback.hook.html#activationstats.after_batch',
                                      'fastai.callback.hook.ActivationStats.before_fit': 'https://docs.fast.ai/callback.hook.html#activationstats.before_fit',
                                      'fastai.callback.hook.ActivationStats.color_dim': 'https://docs.fast.ai/callback.hook.html#activationstats.color_dim',
                                      'fastai.callback.hook.ActivationStats.hist': 'https://docs.fast.ai/callback.hook.html#activationstats.hist',
                                      'fastai.callback.hook.ActivationStats.hook': 'https://docs.fast.ai/callback.hook.html#activationstats.hook',
                                      'fastai.callback.hook.ActivationStats.hook_multi_ouput': 'https://docs.fast.ai/callback.hook.html#activationstats.hook_multi_ouput',
                                      'fastai.callback.hook.ActivationStats.layer_stats': 'https://docs.fast.ai/callback.hook.html#activationstats.layer_stats',
                                      'fastai.callback.hook.ActivationStats.plot_layer_stats': 'https://docs.fast.ai/callback.hook.html#activationstats.plot_layer_stats',
                                      'fastai.callback.hook.Hook': 'https://docs.fast.ai/callback.hook.html#hook',
                                      'fastai.callback.hook.Hook.hook_fn': 'https://docs.fast.ai/callback.hook.html#hook.hook_fn',
                                      'fastai.callback.hook.Hook.remove': 'https://docs.fast.ai/callback.hook.html#hook.remove',
                                      'fastai.callback.hook.HookCallback': 'https://docs.fast.ai/callback.hook.html#hookcallback',
                                      'fastai.callback.hook.HookCallback.after_batch': 'https://docs.fast.ai/callback.hook.html#hookcallback.after_batch',
                                      'fastai.callback.hook.HookCallback.after_fit': 'https://docs.fast.ai/callback.hook.html#hookcallback.after_fit',
                                      'fastai.callback.hook.HookCallback.before_batch': 'https://docs.fast.ai/callback.hook.html#hookcallback.before_batch',
                                      'fastai.callback.hook.HookCallback.before_fit': 'https://docs.fast.ai/callback.hook.html#hookcallback.before_fit',
                                      'fastai.callback.hook.Hooks': 'https://docs.fast.ai/callback.hook.html#hooks',
                                      'fastai.callback.hook.Hooks.remove': 'https://docs.fast.ai/callback.hook.html#hooks.remove',
                                      'fastai.callback.hook.Hooks.stored': 'https://docs.fast.ai/callback.hook.html#hooks.stored',
                                      'fastai.callback.hook.Learner.summary': 'https://docs.fast.ai/callback.hook.html#learner.summary',
                                      'fastai.callback.hook.dummy_eval': 'https://docs.fast.ai/callback.hook.html#dummy_eval',
                                      'fastai.callback.hook.has_params': 'https://docs.fast.ai/callback.hook.html#has_params',
                                      'fastai.callback.hook.hook_output': 'https://docs.fast.ai/callback.hook.html#hook_output',
                                      'fastai.callback.hook.hook_outputs': 'https://docs.fast.ai/callback.hook.html#hook_outputs',
                                      'fastai.callback.hook.layer_info': 'https://docs.fast.ai/callback.hook.html#layer_info',
                                      'fastai.callback.hook.model_sizes': 'https://docs.fast.ai/callback.hook.html#model_sizes',
                                      'fastai.callback.hook.module_summary': 'https://docs.fast.ai/callback.hook.html#module_summary',
                                      'fastai.callback.hook.num_features_model': 'https://docs.fast.ai/callback.hook.html#num_features_model',
                                      'fastai.callback.hook.total_params': 'https://docs.fast.ai/callback.hook.html#total_params'},
            'fastai.callback.mixup': { 'fastai.callback.mixup.CutMix': 'https://docs.fast.ai/callback.mixup.html#cutmix',
                                       'fastai.callback.mixup.CutMix.before_batch': 'https://docs.fast.ai/callback.mixup.html#cutmix.before_batch',
                                       'fastai.callback.mixup.CutMix.rand_bbox': 'https://docs.fast.ai/callback.mixup.html#cutmix.rand_bbox',
                                       'fastai.callback.mixup.MixHandler': 'https://docs.fast.ai/callback.mixup.html#mixhandler',
                                       'fastai.callback.mixup.MixHandler.after_cancel_fit': 'https://docs.fast.ai/callback.mixup.html#mixhandler.after_cancel_fit',
                                       'fastai.callback.mixup.MixHandler.after_cancel_train': 'https://docs.fast.ai/callback.mixup.html#mixhandler.after_cancel_train',
                                       'fastai.callback.mixup.MixHandler.after_train': 'https://docs.fast.ai/callback.mixup.html#mixhandler.after_train',
                                       'fastai.callback.mixup.MixHandler.before_train': 'https://docs.fast.ai/callback.mixup.html#mixhandler.before_train',
                                       'fastai.callback.mixup.MixHandler.lf': 'https://docs.fast.ai/callback.mixup.html#mixhandler.lf',
                                       'fastai.callback.mixup.MixUp': 'https://docs.fast.ai/callback.mixup.html#mixup',
                                       'fastai.callback.mixup.MixUp.before_batch': 'https://docs.fast.ai/callback.mixup.html#mixup.before_batch',
                                       'fastai.callback.mixup.reduce_loss': 'https://docs.fast.ai/callback.mixup.html#reduce_loss'},
            'fastai.callback.neptune': { 'fastai.callback.neptune.NeptuneCallback': 'https://docs.fast.ai/callback.neptune.html#neptunecallback',
                                         'fastai.callback.neptune.NeptuneCallback.after_batch': 'https://docs.fast.ai/callback.neptune.html#neptunecallback.after_batch',
                                         'fastai.callback.neptune.NeptuneCallback.after_epoch': 'https://docs.fast.ai/callback.neptune.html#neptunecallback.after_epoch',
                                         'fastai.callback.neptune.NeptuneCallback.after_fit': 'https://docs.fast.ai/callback.neptune.html#neptunecallback.after_fit',
                                         'fastai.callback.neptune.NeptuneCallback.before_fit': 'https://docs.fast.ai/callback.neptune.html#neptunecallback.before_fit'},
            'fastai.callback.preds': { 'fastai.callback.preds.MCDropoutCallback': 'https://docs.fast.ai/callback.preds.html#mcdropoutcallback',
                                       'fastai.callback.preds.MCDropoutCallback.after_validate': 'https://docs.fast.ai/callback.preds.html#mcdropoutcallback.after_validate',
                                       'fastai.callback.preds.MCDropoutCallback.before_validate': 'https://docs.fast.ai/callback.preds.html#mcdropoutcallback.before_validate'},
            'fastai.callback.progress': { 'fastai.callback.progress.CSVLogger': 'https://docs.fast.ai/callback.progress.html#csvlogger',
                                          'fastai.callback.progress.CSVLogger.after_fit': 'https://docs.fast.ai/callback.progress.html#csvlogger.after_fit',
                                          'fastai.callback.progress.CSVLogger.before_fit': 'https://docs.fast.ai/callback.progress.html#csvlogger.before_fit',
                                          'fastai.callback.progress.CSVLogger.read_log': 'https://docs.fast.ai/callback.progress.html#csvlogger.read_log',
                                          'fastai.callback.progress.Learner.no_bar': 'https://docs.fast.ai/callback.progress.html#learner.no_bar',
                                          'fastai.callback.progress.ProgressCallback': 'https://docs.fast.ai/callback.progress.html#progresscallback',
                                          'fastai.callback.progress.ProgressCallback.after_batch': 'https://docs.fast.ai/callback.progress.html#progresscallback.after_batch',
                                          'fastai.callback.progress.ProgressCallback.after_fit': 'https://docs.fast.ai/callback.progress.html#progresscallback.after_fit',
                                          'fastai.callback.progress.ProgressCallback.after_train': 'https://docs.fast.ai/callback.progress.html#progresscallback.after_train',
                                          'fastai.callback.progress.ProgressCallback.after_validate': 'https://docs.fast.ai/callback.progress.html#progresscallback.after_validate',
                                          'fastai.callback.progress.ProgressCallback.before_epoch': 'https://docs.fast.ai/callback.progress.html#progresscallback.before_epoch',
                                          'fastai.callback.progress.ProgressCallback.before_fit': 'https://docs.fast.ai/callback.progress.html#progresscallback.before_fit',
                                          'fastai.callback.progress.ProgressCallback.before_train': 'https://docs.fast.ai/callback.progress.html#progresscallback.before_train',
                                          'fastai.callback.progress.ProgressCallback.before_validate': 'https://docs.fast.ai/callback.progress.html#progresscallback.before_validate',
                                          'fastai.callback.progress.ShowGraphCallback': 'https://docs.fast.ai/callback.progress.html#showgraphcallback',
                                          'fastai.callback.progress.ShowGraphCallback.after_epoch': 'https://docs.fast.ai/callback.progress.html#showgraphcallback.after_epoch',
                                          'fastai.callback.progress.ShowGraphCallback.after_train': 'https://docs.fast.ai/callback.progress.html#showgraphcallback.after_train',
                                          'fastai.callback.progress.ShowGraphCallback.before_fit': 'https://docs.fast.ai/callback.progress.html#showgraphcallback.before_fit'},
            'fastai.callback.rnn': { 'fastai.callback.rnn.ModelResetter': 'https://docs.fast.ai/callback.rnn.html#modelresetter',
                                     'fastai.callback.rnn.ModelResetter.after_fit': 'https://docs.fast.ai/callback.rnn.html#modelresetter.after_fit',
                                     'fastai.callback.rnn.ModelResetter.before_train': 'https://docs.fast.ai/callback.rnn.html#modelresetter.before_train',
                                     'fastai.callback.rnn.ModelResetter.before_validate': 'https://docs.fast.ai/callback.rnn.html#modelresetter.before_validate',
                                     'fastai.callback.rnn.RNNCallback': 'https://docs.fast.ai/callback.rnn.html#rnncallback',
                                     'fastai.callback.rnn.RNNCallback.after_pred': 'https://docs.fast.ai/callback.rnn.html#rnncallback.after_pred',
                                     'fastai.callback.rnn.RNNRegularizer': 'https://docs.fast.ai/callback.rnn.html#rnnregularizer',
                                     'fastai.callback.rnn.RNNRegularizer.after_loss': 'https://docs.fast.ai/callback.rnn.html#rnnregularizer.after_loss',
                                     'fastai.callback.rnn.rnn_cbs': 'https://docs.fast.ai/callback.rnn.html#rnn_cbs'},
            'fastai.callback.schedule': { 'fastai.callback.schedule.LRFinder': 'https://docs.fast.ai/callback.schedule.html#lrfinder',
                                          'fastai.callback.schedule.LRFinder.after_batch': 'https://docs.fast.ai/callback.schedule.html#lrfinder.after_batch',
                                          'fastai.callback.schedule.LRFinder.after_fit': 'https://docs.fast.ai/callback.schedule.html#lrfinder.after_fit',
                                          'fastai.callback.schedule.LRFinder.before_batch': 'https://docs.fast.ai/callback.schedule.html#lrfinder.before_batch',
                                          'fastai.callback.schedule.LRFinder.before_fit': 'https://docs.fast.ai/callback.schedule.html#lrfinder.before_fit',
                                          'fastai.callback.schedule.LRFinder.before_validate': 'https://docs.fast.ai/callback.schedule.html#lrfinder.before_validate',
                                          'fastai.callback.schedule.Learner.fine_tune': 'https://docs.fast.ai/callback.schedule.html#learner.fine_tune',
                                          'fastai.callback.schedule.Learner.fit_flat_cos': 'https://docs.fast.ai/callback.schedule.html#learner.fit_flat_cos',
                                          'fastai.callback.schedule.Learner.fit_one_cycle': 'https://docs.fast.ai/callback.schedule.html#learner.fit_one_cycle',
                                          'fastai.callback.schedule.Learner.fit_sgdr': 'https://docs.fast.ai/callback.schedule.html#learner.fit_sgdr',
                                          'fastai.callback.schedule.Learner.lr_find': 'https://docs.fast.ai/callback.schedule.html#learner.lr_find',
                                          'fastai.callback.schedule.ParamScheduler': 'https://docs.fast.ai/callback.schedule.html#paramscheduler',
                                          'fastai.callback.schedule.ParamScheduler.after_batch': 'https://docs.fast.ai/callback.schedule.html#paramscheduler.after_batch',
                                          'fastai.callback.schedule.ParamScheduler.after_fit': 'https://docs.fast.ai/callback.schedule.html#paramscheduler.after_fit',
                                          'fastai.callback.schedule.ParamScheduler.before_batch': 'https://docs.fast.ai/callback.schedule.html#paramscheduler.before_batch',
                                          'fastai.callback.schedule.ParamScheduler.before_fit': 'https://docs.fast.ai/callback.schedule.html#paramscheduler.before_fit',
                                          'fastai.callback.schedule.Recorder.plot_lr_find': 'https://docs.fast.ai/callback.schedule.html#recorder.plot_lr_find',
                                          'fastai.callback.schedule.Recorder.plot_sched': 'https://docs.fast.ai/callback.schedule.html#recorder.plot_sched',
                                          'fastai.callback.schedule.SchedCos': 'https://docs.fast.ai/callback.schedule.html#schedcos',
                                          'fastai.callback.schedule.SchedExp': 'https://docs.fast.ai/callback.schedule.html#schedexp',
                                          'fastai.callback.schedule.SchedLin': 'https://docs.fast.ai/callback.schedule.html#schedlin',
                                          'fastai.callback.schedule.SchedNo': 'https://docs.fast.ai/callback.schedule.html#schedno',
                                          'fastai.callback.schedule.SchedPoly': 'https://docs.fast.ai/callback.schedule.html#schedpoly',
                                          'fastai.callback.schedule.SuggestionMethod': 'https://docs.fast.ai/callback.schedule.html#suggestionmethod',
                                          'fastai.callback.schedule.annealer': 'https://docs.fast.ai/callback.schedule.html#annealer',
                                          'fastai.callback.schedule.combine_scheds': 'https://docs.fast.ai/callback.schedule.html#combine_scheds',
                                          'fastai.callback.schedule.combined_cos': 'https://docs.fast.ai/callback.schedule.html#combined_cos',
                                          'fastai.callback.schedule.minimum': 'https://docs.fast.ai/callback.schedule.html#minimum',
                                          'fastai.callback.schedule.sched_cos': 'https://docs.fast.ai/callback.schedule.html#sched_cos',
                                          'fastai.callback.schedule.sched_exp': 'https://docs.fast.ai/callback.schedule.html#sched_exp',
                                          'fastai.callback.schedule.sched_lin': 'https://docs.fast.ai/callback.schedule.html#sched_lin',
                                          'fastai.callback.schedule.sched_no': 'https://docs.fast.ai/callback.schedule.html#sched_no',
                                          'fastai.callback.schedule.slide': 'https://docs.fast.ai/callback.schedule.html#slide',
                                          'fastai.callback.schedule.steep': 'https://docs.fast.ai/callback.schedule.html#steep',
                                          'fastai.callback.schedule.valley': 'https://docs.fast.ai/callback.schedule.html#valley'},
            'fastai.callback.tensorboard': { 'fastai.callback.tensorboard.TensorBoardBaseCallback': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardbasecallback',
                                             'fastai.callback.tensorboard.TensorBoardBaseCallback.after_fit': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardbasecallback.after_fit',
                                             'fastai.callback.tensorboard.TensorBoardBaseCallback.after_pred': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardbasecallback.after_pred',
                                             'fastai.callback.tensorboard.TensorBoardBaseCallback.after_validate': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardbasecallback.after_validate',
                                             'fastai.callback.tensorboard.TensorBoardCallback': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardcallback',
                                             'fastai.callback.tensorboard.TensorBoardCallback.after_batch': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardcallback.after_batch',
                                             'fastai.callback.tensorboard.TensorBoardCallback.after_epoch': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardcallback.after_epoch',
                                             'fastai.callback.tensorboard.TensorBoardCallback.before_fit': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardcallback.before_fit',
                                             'fastai.callback.tensorboard.TensorBoardCallback.before_validate': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardcallback.before_validate',
                                             'fastai.callback.tensorboard.TensorBoardProjectorCallback': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardprojectorcallback',
                                             'fastai.callback.tensorboard.TensorBoardProjectorCallback.before_fit': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardprojectorcallback.before_fit',
                                             'fastai.callback.tensorboard.TensorBoardProjectorCallback.before_validate': 'https://docs.fast.ai/callback.tensorboard.html#tensorboardprojectorcallback.before_validate',
                                             'fastai.callback.tensorboard.projector_word_embeddings': 'https://docs.fast.ai/callback.tensorboard.html#projector_word_embeddings',
                                             'fastai.callback.tensorboard.tensorboard_log': 'https://docs.fast.ai/callback.tensorboard.html#tensorboard_log'},
            'fastai.callback.tracker': { 'fastai.callback.tracker.EarlyStoppingCallback': 'https://docs.fast.ai/callback.tracker.html#earlystoppingcallback',
                                         'fastai.callback.tracker.EarlyStoppingCallback.after_epoch': 'https://docs.fast.ai/callback.tracker.html#earlystoppingcallback.after_epoch',
                                         'fastai.callback.tracker.EarlyStoppingCallback.before_fit': 'https://docs.fast.ai/callback.tracker.html#earlystoppingcallback.before_fit',
                                         'fastai.callback.tracker.ReduceLROnPlateau': 'https://docs.fast.ai/callback.tracker.html#reducelronplateau',
                                         'fastai.callback.tracker.ReduceLROnPlateau.after_epoch': 'https://docs.fast.ai/callback.tracker.html#reducelronplateau.after_epoch',
                                         'fastai.callback.tracker.ReduceLROnPlateau.before_fit': 'https://docs.fast.ai/callback.tracker.html#reducelronplateau.before_fit',
                                         'fastai.callback.tracker.SaveModelCallback': 'https://docs.fast.ai/callback.tracker.html#savemodelcallback',
                                         'fastai.callback.tracker.SaveModelCallback.after_epoch': 'https://docs.fast.ai/callback.tracker.html#savemodelcallback.after_epoch',
                                         'fastai.callback.tracker.SaveModelCallback.after_fit': 'https://docs.fast.ai/callback.tracker.html#savemodelcallback.after_fit',
                                         'fastai.callback.tracker.TerminateOnNaNCallback': 'https://docs.fast.ai/callback.tracker.html#terminateonnancallback',
                                         'fastai.callback.tracker.TerminateOnNaNCallback.after_batch': 'https://docs.fast.ai/callback.tracker.html#terminateonnancallback.after_batch',
                                         'fastai.callback.tracker.TrackerCallback': 'https://docs.fast.ai/callback.tracker.html#trackercallback',
                                         'fastai.callback.tracker.TrackerCallback.after_epoch': 'https://docs.fast.ai/callback.tracker.html#trackercallback.after_epoch',
                                         'fastai.callback.tracker.TrackerCallback.after_fit': 'https://docs.fast.ai/callback.tracker.html#trackercallback.after_fit',
                                         'fastai.callback.tracker.TrackerCallback.before_fit': 'https://docs.fast.ai/callback.tracker.html#trackercallback.before_fit'},
            'fastai.callback.training': { 'fastai.callback.training.BnFreeze': 'https://docs.fast.ai/callback.training.html#bnfreeze',
                                          'fastai.callback.training.BnFreeze.before_train': 'https://docs.fast.ai/callback.training.html#bnfreeze.before_train',
                                          'fastai.callback.training.ChannelsLast': 'https://docs.fast.ai/callback.training.html#channelslast',
                                          'fastai.callback.training.ChannelsLast.before_batch': 'https://docs.fast.ai/callback.training.html#channelslast.before_batch',
                                          'fastai.callback.training.ChannelsLast.before_fit': 'https://docs.fast.ai/callback.training.html#channelslast.before_fit',
                                          'fastai.callback.training.GradientAccumulation': 'https://docs.fast.ai/callback.training.html#gradientaccumulation',
                                          'fastai.callback.training.GradientAccumulation.after_loss': 'https://docs.fast.ai/callback.training.html#gradientaccumulation.after_loss',
                                          'fastai.callback.training.GradientAccumulation.before_fit': 'https://docs.fast.ai/callback.training.html#gradientaccumulation.before_fit',
                                          'fastai.callback.training.GradientAccumulation.before_step': 'https://docs.fast.ai/callback.training.html#gradientaccumulation.before_step',
                                          'fastai.callback.training.GradientClip': 'https://docs.fast.ai/callback.training.html#gradientclip',
                                          'fastai.callback.training.GradientClip.before_step': 'https://docs.fast.ai/callback.training.html#gradientclip.before_step',
                                          'fastai.callback.training.ShortEpochCallback': 'https://docs.fast.ai/callback.training.html#shortepochcallback',
                                          'fastai.callback.training.ShortEpochCallback.after_batch': 'https://docs.fast.ai/callback.training.html#shortepochcallback.after_batch',
                                          'fastai.callback.training.bn_types': 'https://docs.fast.ai/callback.training.html#bn_types',
                                          'fastai.callback.training.set_bn_eval': 'https://docs.fast.ai/callback.training.html#set_bn_eval'},
            'fastai.callback.wandb': { 'fastai.callback.wandb.Learner.gather_args': 'https://docs.fast.ai/callback.wandb.html#learner.gather_args',
                                       'fastai.callback.wandb.WandbCallback': 'https://docs.fast.ai/callback.wandb.html#wandbcallback',
                                       'fastai.callback.wandb.WandbCallback.after_batch': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.after_batch',
                                       'fastai.callback.wandb.WandbCallback.after_create': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.after_create',
                                       'fastai.callback.wandb.WandbCallback.after_epoch': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.after_epoch',
                                       'fastai.callback.wandb.WandbCallback.after_fit': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.after_fit',
                                       'fastai.callback.wandb.WandbCallback.before_batch': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.before_batch',
                                       'fastai.callback.wandb.WandbCallback.before_fit': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.before_fit',
                                       'fastai.callback.wandb.WandbCallback.log_predictions': 'https://docs.fast.ai/callback.wandb.html#wandbcallback.log_predictions',
                                       'fastai.callback.wandb.log_dataset': 'https://docs.fast.ai/callback.wandb.html#log_dataset',
                                       'fastai.callback.wandb.log_model': 'https://docs.fast.ai/callback.wandb.html#log_model',
                                       'fastai.callback.wandb.wandb_process': 'https://docs.fast.ai/callback.wandb.html#wandb_process'},
            'fastai.collab': { 'fastai.collab.CollabDataLoaders': 'https://docs.fast.ai/collab.html#collabdataloaders',
                               'fastai.collab.CollabDataLoaders.from_csv': 'https://docs.fast.ai/collab.html#collabdataloaders.from_csv',
                               'fastai.collab.CollabDataLoaders.from_df': 'https://docs.fast.ai/collab.html#collabdataloaders.from_df',
                               'fastai.collab.EmbeddingDotBias': 'https://docs.fast.ai/collab.html#embeddingdotbias',
                               'fastai.collab.EmbeddingDotBias.bias': 'https://docs.fast.ai/collab.html#embeddingdotbias.bias',
                               'fastai.collab.EmbeddingDotBias.forward': 'https://docs.fast.ai/collab.html#embeddingdotbias.forward',
                               'fastai.collab.EmbeddingDotBias.from_classes': 'https://docs.fast.ai/collab.html#embeddingdotbias.from_classes',
                               'fastai.collab.EmbeddingDotBias.weight': 'https://docs.fast.ai/collab.html#embeddingdotbias.weight',
                               'fastai.collab.EmbeddingNN': 'https://docs.fast.ai/collab.html#embeddingnn',
                               'fastai.collab.TabularCollab': 'https://docs.fast.ai/collab.html#tabularcollab',
                               'fastai.collab.collab_learner': 'https://docs.fast.ai/collab.html#collab_learner'},
            'fastai.data.all': {},
            'fastai.data.block': { 'fastai.data.block.CategoryBlock': 'https://docs.fast.ai/data.block.html#categoryblock',
                                   'fastai.data.block.DataBlock': 'https://docs.fast.ai/data.block.html#datablock',
                                   'fastai.data.block.DataBlock.dataloaders': 'https://docs.fast.ai/data.block.html#datablock.dataloaders',
                                   'fastai.data.block.DataBlock.datasets': 'https://docs.fast.ai/data.block.html#datablock.datasets',
                                   'fastai.data.block.DataBlock.from_columns': 'https://docs.fast.ai/data.block.html#datablock.from_columns',
                                   'fastai.data.block.DataBlock.new': 'https://docs.fast.ai/data.block.html#datablock.new',
                                   'fastai.data.block.DataBlock.summary': 'https://docs.fast.ai/data.block.html#datablock.summary',
                                   'fastai.data.block.MultiCategoryBlock': 'https://docs.fast.ai/data.block.html#multicategoryblock',
                                   'fastai.data.block.RegressionBlock': 'https://docs.fast.ai/data.block.html#regressionblock',
                                   'fastai.data.block.TransformBlock': 'https://docs.fast.ai/data.block.html#transformblock'},
            'fastai.data.core': { 'fastai.data.core.DataLoaders': 'https://docs.fast.ai/data.core.html#dataloaders',
                                  'fastai.data.core.DataLoaders.add_tfms': 'https://docs.fast.ai/data.core.html#dataloaders.add_tfms',
                                  'fastai.data.core.DataLoaders.cpu': 'https://docs.fast.ai/data.core.html#dataloaders.cpu',
                                  'fastai.data.core.DataLoaders.cuda': 'https://docs.fast.ai/data.core.html#dataloaders.cuda',
                                  'fastai.data.core.DataLoaders.device': 'https://docs.fast.ai/data.core.html#dataloaders.device',
                                  'fastai.data.core.DataLoaders.from_dblock': 'https://docs.fast.ai/data.core.html#dataloaders.from_dblock',
                                  'fastai.data.core.DataLoaders.from_dsets': 'https://docs.fast.ai/data.core.html#dataloaders.from_dsets',
                                  'fastai.data.core.DataLoaders.new_empty': 'https://docs.fast.ai/data.core.html#dataloaders.new_empty',
                                  'fastai.data.core.DataLoaders.test_dl': 'https://docs.fast.ai/data.core.html#dataloaders.test_dl',
                                  'fastai.data.core.DataLoaders.to': 'https://docs.fast.ai/data.core.html#dataloaders.to',
                                  'fastai.data.core.Datasets': 'https://docs.fast.ai/data.core.html#datasets',
                                  'fastai.data.core.Datasets.decode': 'https://docs.fast.ai/data.core.html#datasets.decode',
                                  'fastai.data.core.Datasets.items': 'https://docs.fast.ai/data.core.html#datasets.items',
                                  'fastai.data.core.Datasets.new_empty': 'https://docs.fast.ai/data.core.html#datasets.new_empty',
                                  'fastai.data.core.Datasets.overlapping_splits': 'https://docs.fast.ai/data.core.html#datasets.overlapping_splits',
                                  'fastai.data.core.Datasets.set_split_idx': 'https://docs.fast.ai/data.core.html#datasets.set_split_idx',
                                  'fastai.data.core.Datasets.show': 'https://docs.fast.ai/data.core.html#datasets.show',
                                  'fastai.data.core.Datasets.split_idx': 'https://docs.fast.ai/data.core.html#datasets.split_idx',
                                  'fastai.data.core.Datasets.splits': 'https://docs.fast.ai/data.core.html#datasets.splits',
                                  'fastai.data.core.Datasets.subset': 'https://docs.fast.ai/data.core.html#datasets.subset',
                                  'fastai.data.core.FilteredBase': 'https://docs.fast.ai/data.core.html#filteredbase',
                                  'fastai.data.core.FilteredBase.dataloaders': 'https://docs.fast.ai/data.core.html#filteredbase.dataloaders',
                                  'fastai.data.core.FilteredBase.n_subsets': 'https://docs.fast.ai/data.core.html#filteredbase.n_subsets',
                                  'fastai.data.core.FilteredBase.subset': 'https://docs.fast.ai/data.core.html#filteredbase.subset',
                                  'fastai.data.core.TfmdDL': 'https://docs.fast.ai/data.core.html#tfmddl',
                                  'fastai.data.core.TfmdDL.before_iter': 'https://docs.fast.ai/data.core.html#tfmddl.before_iter',
                                  'fastai.data.core.TfmdDL.decode': 'https://docs.fast.ai/data.core.html#tfmddl.decode',
                                  'fastai.data.core.TfmdDL.decode_batch': 'https://docs.fast.ai/data.core.html#tfmddl.decode_batch',
                                  'fastai.data.core.TfmdDL.n_inp': 'https://docs.fast.ai/data.core.html#tfmddl.n_inp',
                                  'fastai.data.core.TfmdDL.new': 'https://docs.fast.ai/data.core.html#tfmddl.new',
                                  'fastai.data.core.TfmdDL.show_batch': 'https://docs.fast.ai/data.core.html#tfmddl.show_batch',
                                  'fastai.data.core.TfmdDL.show_results': 'https://docs.fast.ai/data.core.html#tfmddl.show_results',
                                  'fastai.data.core.TfmdDL.to': 'https://docs.fast.ai/data.core.html#tfmddl.to',
                                  'fastai.data.core.TfmdLists': 'https://docs.fast.ai/data.core.html#tfmdlists',
                                  'fastai.data.core.TfmdLists.decode': 'https://docs.fast.ai/data.core.html#tfmdlists.decode',
                                  'fastai.data.core.TfmdLists.infer': 'https://docs.fast.ai/data.core.html#tfmdlists.infer',
                                  'fastai.data.core.TfmdLists.infer_idx': 'https://docs.fast.ai/data.core.html#tfmdlists.infer_idx',
                                  'fastai.data.core.TfmdLists.new_empty': 'https://docs.fast.ai/data.core.html#tfmdlists.new_empty',
                                  'fastai.data.core.TfmdLists.overlapping_splits': 'https://docs.fast.ai/data.core.html#tfmdlists.overlapping_splits',
                                  'fastai.data.core.TfmdLists.setup': 'https://docs.fast.ai/data.core.html#tfmdlists.setup',
                                  'fastai.data.core.TfmdLists.show': 'https://docs.fast.ai/data.core.html#tfmdlists.show',
                                  'fastai.data.core.TfmdLists.subset': 'https://docs.fast.ai/data.core.html#tfmdlists.subset',
                                  'fastai.data.core.decode_at': 'https://docs.fast.ai/data.core.html#decode_at',
                                  'fastai.data.core.show_at': 'https://docs.fast.ai/data.core.html#show_at',
                                  'fastai.data.core.show_batch': 'https://docs.fast.ai/data.core.html#show_batch',
                                  'fastai.data.core.show_results': 'https://docs.fast.ai/data.core.html#show_results',
                                  'fastai.data.core.test_set': 'https://docs.fast.ai/data.core.html#test_set'},
            'fastai.data.download_checks': {},
            'fastai.data.external': { 'fastai.data.external.URLs': 'https://docs.fast.ai/data.external.html#urls',
                                      'fastai.data.external.URLs.path': 'https://docs.fast.ai/data.external.html#urls.path',
                                      'fastai.data.external.fastai_cfg': 'https://docs.fast.ai/data.external.html#fastai_cfg',
                                      'fastai.data.external.fastai_path': 'https://docs.fast.ai/data.external.html#fastai_path',
                                      'fastai.data.external.untar_data': 'https://docs.fast.ai/data.external.html#untar_data'},
            'fastai.data.load': { 'fastai.data.load.DataLoader': 'https://docs.fast.ai/data.load.html#dataloader',
                                  'fastai.data.load.DataLoader.chunkify': 'https://docs.fast.ai/data.load.html#dataloader.chunkify',
                                  'fastai.data.load.DataLoader.create_batch': 'https://docs.fast.ai/data.load.html#dataloader.create_batch',
                                  'fastai.data.load.DataLoader.create_batches': 'https://docs.fast.ai/data.load.html#dataloader.create_batches',
                                  'fastai.data.load.DataLoader.create_item': 'https://docs.fast.ai/data.load.html#dataloader.create_item',
                                  'fastai.data.load.DataLoader.do_batch': 'https://docs.fast.ai/data.load.html#dataloader.do_batch',
                                  'fastai.data.load.DataLoader.do_item': 'https://docs.fast.ai/data.load.html#dataloader.do_item',
                                  'fastai.data.load.DataLoader.get_idxs': 'https://docs.fast.ai/data.load.html#dataloader.get_idxs',
                                  'fastai.data.load.DataLoader.new': 'https://docs.fast.ai/data.load.html#dataloader.new',
                                  'fastai.data.load.DataLoader.one_batch': 'https://docs.fast.ai/data.load.html#dataloader.one_batch',
                                  'fastai.data.load.DataLoader.prebatched': 'https://docs.fast.ai/data.load.html#dataloader.prebatched',
                                  'fastai.data.load.DataLoader.randomize': 'https://docs.fast.ai/data.load.html#dataloader.randomize',
                                  'fastai.data.load.DataLoader.retain': 'https://docs.fast.ai/data.load.html#dataloader.retain',
                                  'fastai.data.load.DataLoader.sample': 'https://docs.fast.ai/data.load.html#dataloader.sample',
                                  'fastai.data.load.DataLoader.shuffle_fn': 'https://docs.fast.ai/data.load.html#dataloader.shuffle_fn',
                                  'fastai.data.load.DataLoader.to': 'https://docs.fast.ai/data.load.html#dataloader.to',
                                  'fastai.data.load.SkipItemException': 'https://docs.fast.ai/data.load.html#skipitemexception',
                                  'fastai.data.load.collate_error': 'https://docs.fast.ai/data.load.html#collate_error',
                                  'fastai.data.load.fa_collate': 'https://docs.fast.ai/data.load.html#fa_collate',
                                  'fastai.data.load.fa_convert': 'https://docs.fast.ai/data.load.html#fa_convert'},
            'fastai.data.transforms': { 'fastai.data.transforms.AttrGetter': 'https://docs.fast.ai/data.transforms.html#attrgetter',
                                        'fastai.data.transforms.AttrGetter.encodes': 'https://docs.fast.ai/data.transforms.html#attrgetter.encodes',
                                        'fastai.data.transforms.Categorize': 'https://docs.fast.ai/data.transforms.html#categorize',
                                        'fastai.data.transforms.Categorize.decodes': 'https://docs.fast.ai/data.transforms.html#categorize.decodes',
                                        'fastai.data.transforms.Categorize.encodes': 'https://docs.fast.ai/data.transforms.html#categorize.encodes',
                                        'fastai.data.transforms.Categorize.setups': 'https://docs.fast.ai/data.transforms.html#categorize.setups',
                                        'fastai.data.transforms.Category': 'https://docs.fast.ai/data.transforms.html#category',
                                        'fastai.data.transforms.CategoryMap': 'https://docs.fast.ai/data.transforms.html#categorymap',
                                        'fastai.data.transforms.CategoryMap.map_ids': 'https://docs.fast.ai/data.transforms.html#categorymap.map_ids',
                                        'fastai.data.transforms.CategoryMap.map_objs': 'https://docs.fast.ai/data.transforms.html#categorymap.map_objs',
                                        'fastai.data.transforms.ColReader': 'https://docs.fast.ai/data.transforms.html#colreader',
                                        'fastai.data.transforms.ColSplitter': 'https://docs.fast.ai/data.transforms.html#colsplitter',
                                        'fastai.data.transforms.EncodedMultiCategorize': 'https://docs.fast.ai/data.transforms.html#encodedmulticategorize',
                                        'fastai.data.transforms.EncodedMultiCategorize.decodes': 'https://docs.fast.ai/data.transforms.html#encodedmulticategorize.decodes',
                                        'fastai.data.transforms.EncodedMultiCategorize.encodes': 'https://docs.fast.ai/data.transforms.html#encodedmulticategorize.encodes',
                                        'fastai.data.transforms.EndSplitter': 'https://docs.fast.ai/data.transforms.html#endsplitter',
                                        'fastai.data.transforms.FileGetter': 'https://docs.fast.ai/data.transforms.html#filegetter',
                                        'fastai.data.transforms.FileSplitter': 'https://docs.fast.ai/data.transforms.html#filesplitter',
                                        'fastai.data.transforms.FuncSplitter': 'https://docs.fast.ai/data.transforms.html#funcsplitter',
                                        'fastai.data.transforms.GrandparentSplitter': 'https://docs.fast.ai/data.transforms.html#grandparentsplitter',
                                        'fastai.data.transforms.ImageGetter': 'https://docs.fast.ai/data.transforms.html#imagegetter',
                                        'fastai.data.transforms.IndexSplitter': 'https://docs.fast.ai/data.transforms.html#indexsplitter',
                                        'fastai.data.transforms.IntToFloatTensor': 'https://docs.fast.ai/data.transforms.html#inttofloattensor',
                                        'fastai.data.transforms.IntToFloatTensor.decodes': 'https://docs.fast.ai/data.transforms.html#inttofloattensor.decodes',
                                        'fastai.data.transforms.IntToFloatTensor.encodes': 'https://docs.fast.ai/data.transforms.html#inttofloattensor.encodes',
                                        'fastai.data.transforms.ItemGetter': 'https://docs.fast.ai/data.transforms.html#itemgetter',
                                        'fastai.data.transforms.ItemGetter.encodes': 'https://docs.fast.ai/data.transforms.html#itemgetter.encodes',
                                        'fastai.data.transforms.MaskSplitter': 'https://docs.fast.ai/data.transforms.html#masksplitter',
                                        'fastai.data.transforms.MultiCategorize': 'https://docs.fast.ai/data.transforms.html#multicategorize',
                                        'fastai.data.transforms.MultiCategorize.decodes': 'https://docs.fast.ai/data.transforms.html#multicategorize.decodes',
                                        'fastai.data.transforms.MultiCategorize.encodes': 'https://docs.fast.ai/data.transforms.html#multicategorize.encodes',
                                        'fastai.data.transforms.MultiCategorize.setups': 'https://docs.fast.ai/data.transforms.html#multicategorize.setups',
                                        'fastai.data.transforms.MultiCategory': 'https://docs.fast.ai/data.transforms.html#multicategory',
                                        'fastai.data.transforms.MultiCategory.show': 'https://docs.fast.ai/data.transforms.html#multicategory.show',
                                        'fastai.data.transforms.Normalize': 'https://docs.fast.ai/data.transforms.html#normalize',
                                        'fastai.data.transforms.Normalize.decodes': 'https://docs.fast.ai/data.transforms.html#normalize.decodes',
                                        'fastai.data.transforms.Normalize.encodes': 'https://docs.fast.ai/data.transforms.html#normalize.encodes',
                                        'fastai.data.transforms.Normalize.from_stats': 'https://docs.fast.ai/data.transforms.html#normalize.from_stats',
                                        'fastai.data.transforms.Normalize.setups': 'https://docs.fast.ai/data.transforms.html#normalize.setups',
                                        'fastai.data.transforms.OneHotEncode': 'https://docs.fast.ai/data.transforms.html#onehotencode',
                                        'fastai.data.transforms.OneHotEncode.decodes': 'https://docs.fast.ai/data.transforms.html#onehotencode.decodes',
                                        'fastai.data.transforms.OneHotEncode.encodes': 'https://docs.fast.ai/data.transforms.html#onehotencode.encodes',
                                        'fastai.data.transforms.OneHotEncode.setups': 'https://docs.fast.ai/data.transforms.html#onehotencode.setups',
                                        'fastai.data.transforms.RandomSplitter': 'https://docs.fast.ai/data.transforms.html#randomsplitter',
                                        'fastai.data.transforms.RandomSubsetSplitter': 'https://docs.fast.ai/data.transforms.html#randomsubsetsplitter',
                                        'fastai.data.transforms.RegexLabeller': 'https://docs.fast.ai/data.transforms.html#regexlabeller',
                                        'fastai.data.transforms.RegressionSetup': 'https://docs.fast.ai/data.transforms.html#regressionsetup',
                                        'fastai.data.transforms.RegressionSetup.decodes': 'https://docs.fast.ai/data.transforms.html#regressionsetup.decodes',
                                        'fastai.data.transforms.RegressionSetup.encodes': 'https://docs.fast.ai/data.transforms.html#regressionsetup.encodes',
                                        'fastai.data.transforms.RegressionSetup.setups': 'https://docs.fast.ai/data.transforms.html#regressionsetup.setups',
                                        'fastai.data.transforms.ToTensor': 'https://docs.fast.ai/data.transforms.html#totensor',
                                        'fastai.data.transforms.TrainTestSplitter': 'https://docs.fast.ai/data.transforms.html#traintestsplitter',
                                        'fastai.data.transforms.broadcast_vec': 'https://docs.fast.ai/data.transforms.html#broadcast_vec',
                                        'fastai.data.transforms.get_c': 'https://docs.fast.ai/data.transforms.html#get_c',
                                        'fastai.data.transforms.get_files': 'https://docs.fast.ai/data.transforms.html#get_files',
                                        'fastai.data.transforms.get_image_files': 'https://docs.fast.ai/data.transforms.html#get_image_files',
                                        'fastai.data.transforms.get_text_files': 'https://docs.fast.ai/data.transforms.html#get_text_files',
                                        'fastai.data.transforms.image_extensions': 'https://docs.fast.ai/data.transforms.html#image_extensions',
                                        'fastai.data.transforms.parent_label': 'https://docs.fast.ai/data.transforms.html#parent_label'},
            'fastai.distributed': { 'fastai.distributed.DataParallel.reset': 'https://docs.fast.ai/distributed.html#dataparallel.reset',
                                    'fastai.distributed.DistributedDL': 'https://docs.fast.ai/distributed.html#distributeddl',
                                    'fastai.distributed.DistributedDL.after_batch': 'https://docs.fast.ai/distributed.html#distributeddl.after_batch',
                                    'fastai.distributed.DistributedDL.after_iter': 'https://docs.fast.ai/distributed.html#distributeddl.after_iter',
                                    'fastai.distributed.DistributedDL.before_iter': 'https://docs.fast.ai/distributed.html#distributeddl.before_iter',
                                    'fastai.distributed.DistributedDL.create_batches': 'https://docs.fast.ai/distributed.html#distributeddl.create_batches',
                                    'fastai.distributed.DistributedDL.get_idxs': 'https://docs.fast.ai/distributed.html#distributeddl.get_idxs',
                                    'fastai.distributed.DistributedDL.randomize': 'https://docs.fast.ai/distributed.html#distributeddl.randomize',
                                    'fastai.distributed.DistributedDL.to_detach': 'https://docs.fast.ai/distributed.html#distributeddl.to_detach',
                                    'fastai.distributed.DistributedDataParallel.reset': 'https://docs.fast.ai/distributed.html#distributeddataparallel.reset',
                                    'fastai.distributed.DistributedTrainer': 'https://docs.fast.ai/distributed.html#distributedtrainer',
                                    'fastai.distributed.DistributedTrainer.after_fit': 'https://docs.fast.ai/distributed.html#distributedtrainer.after_fit',
                                    'fastai.distributed.DistributedTrainer.before_fit': 'https://docs.fast.ai/distributed.html#distributedtrainer.before_fit',
                                    'fastai.distributed.DistributedTrainer.before_train': 'https://docs.fast.ai/distributed.html#distributedtrainer.before_train',
                                    'fastai.distributed.DistributedTrainer.before_validate': 'https://docs.fast.ai/distributed.html#distributedtrainer.before_validate',
                                    'fastai.distributed.Learner.detach_distributed': 'https://docs.fast.ai/distributed.html#learner.detach_distributed',
                                    'fastai.distributed.Learner.detach_parallel': 'https://docs.fast.ai/distributed.html#learner.detach_parallel',
                                    'fastai.distributed.Learner.distrib_ctx': 'https://docs.fast.ai/distributed.html#learner.distrib_ctx',
                                    'fastai.distributed.Learner.parallel_ctx': 'https://docs.fast.ai/distributed.html#learner.parallel_ctx',
                                    'fastai.distributed.Learner.to_distributed': 'https://docs.fast.ai/distributed.html#learner.to_distributed',
                                    'fastai.distributed.Learner.to_parallel': 'https://docs.fast.ai/distributed.html#learner.to_parallel',
                                    'fastai.distributed.ParallelTrainer': 'https://docs.fast.ai/distributed.html#paralleltrainer',
                                    'fastai.distributed.ParallelTrainer.after_fit': 'https://docs.fast.ai/distributed.html#paralleltrainer.after_fit',
                                    'fastai.distributed.ParallelTrainer.before_fit': 'https://docs.fast.ai/distributed.html#paralleltrainer.before_fit',
                                    'fastai.distributed.rank0_first': 'https://docs.fast.ai/distributed.html#rank0_first',
                                    'fastai.distributed.setup_distrib': 'https://docs.fast.ai/distributed.html#setup_distrib',
                                    'fastai.distributed.teardown_distrib': 'https://docs.fast.ai/distributed.html#teardown_distrib'},
            'fastai.fp16_utils': { 'fastai.fp16_utils.BN_convert_float': 'https://docs.fast.ai/fp16_utils.html#bn_convert_float',
                                   'fastai.fp16_utils.FP16Model': 'https://docs.fast.ai/fp16_utils.html#fp16model',
                                   'fastai.fp16_utils.FP16Model.forward': 'https://docs.fast.ai/fp16_utils.html#fp16model.forward',
                                   'fastai.fp16_utils.backwards_debug_hook': 'https://docs.fast.ai/fp16_utils.html#backwards_debug_hook',
                                   'fastai.fp16_utils.convert_module': 'https://docs.fast.ai/fp16_utils.html#convert_module',
                                   'fastai.fp16_utils.convert_network': 'https://docs.fast.ai/fp16_utils.html#convert_network',
                                   'fastai.fp16_utils.master_params_to_model_params': 'https://docs.fast.ai/fp16_utils.html#master_params_to_model_params',
                                   'fastai.fp16_utils.model_grads_to_master_grads': 'https://docs.fast.ai/fp16_utils.html#model_grads_to_master_grads',
                                   'fastai.fp16_utils.network_to_half': 'https://docs.fast.ai/fp16_utils.html#network_to_half',
                                   'fastai.fp16_utils.prep_param_lists': 'https://docs.fast.ai/fp16_utils.html#prep_param_lists',
                                   'fastai.fp16_utils.to_python_float': 'https://docs.fast.ai/fp16_utils.html#to_python_float',
                                   'fastai.fp16_utils.tofp16': 'https://docs.fast.ai/fp16_utils.html#tofp16',
                                   'fastai.fp16_utils.tofp16.forward': 'https://docs.fast.ai/fp16_utils.html#tofp16.forward'},
            'fastai.imports': { 'fastai.imports.NoneType': 'https://docs.fast.ai/imports.html#nonetype',
                                'fastai.imports.all_equal': 'https://docs.fast.ai/imports.html#all_equal',
                                'fastai.imports.equals': 'https://docs.fast.ai/imports.html#equals',
                                'fastai.imports.is_coll': 'https://docs.fast.ai/imports.html#is_coll',
                                'fastai.imports.is_iter': 'https://docs.fast.ai/imports.html#is_iter',
                                'fastai.imports.noop': 'https://docs.fast.ai/imports.html#noop',
                                'fastai.imports.noops': 'https://docs.fast.ai/imports.html#noops',
                                'fastai.imports.one_is_instance': 'https://docs.fast.ai/imports.html#one_is_instance',
                                'fastai.imports.pv': 'https://docs.fast.ai/imports.html#pv',
                                'fastai.imports.string_classes': 'https://docs.fast.ai/imports.html#string_classes'},
            'fastai.interpret': { 'fastai.interpret.ClassificationInterpretation': 'https://docs.fast.ai/interpret.html#classificationinterpretation',
                                  'fastai.interpret.ClassificationInterpretation.confusion_matrix': 'https://docs.fast.ai/interpret.html#classificationinterpretation.confusion_matrix',
                                  'fastai.interpret.ClassificationInterpretation.most_confused': 'https://docs.fast.ai/interpret.html#classificationinterpretation.most_confused',
                                  'fastai.interpret.ClassificationInterpretation.plot_confusion_matrix': 'https://docs.fast.ai/interpret.html#classificationinterpretation.plot_confusion_matrix',
                                  'fastai.interpret.ClassificationInterpretation.print_classification_report': 'https://docs.fast.ai/interpret.html#classificationinterpretation.print_classification_report',
                                  'fastai.interpret.Interpretation': 'https://docs.fast.ai/interpret.html#interpretation',
                                  'fastai.interpret.Interpretation.from_learner': 'https://docs.fast.ai/interpret.html#interpretation.from_learner',
                                  'fastai.interpret.Interpretation.plot_top_losses': 'https://docs.fast.ai/interpret.html#interpretation.plot_top_losses',
                                  'fastai.interpret.Interpretation.show_results': 'https://docs.fast.ai/interpret.html#interpretation.show_results',
                                  'fastai.interpret.Interpretation.top_losses': 'https://docs.fast.ai/interpret.html#interpretation.top_losses',
                                  'fastai.interpret.SegmentationInterpretation': 'https://docs.fast.ai/interpret.html#segmentationinterpretation',
                                  'fastai.interpret.plot_top_losses': 'https://docs.fast.ai/interpret.html#plot_top_losses'},
            'fastai.layers': { 'fastai.layers.AdaptiveAvgPool': 'https://docs.fast.ai/layers.html#adaptiveavgpool',
                               'fastai.layers.AdaptiveConcatPool1d': 'https://docs.fast.ai/layers.html#adaptiveconcatpool1d',
                               'fastai.layers.AdaptiveConcatPool1d.forward': 'https://docs.fast.ai/layers.html#adaptiveconcatpool1d.forward',
                               'fastai.layers.AdaptiveConcatPool2d': 'https://docs.fast.ai/layers.html#adaptiveconcatpool2d',
                               'fastai.layers.AdaptiveConcatPool2d.forward': 'https://docs.fast.ai/layers.html#adaptiveconcatpool2d.forward',
                               'fastai.layers.AvgPool': 'https://docs.fast.ai/layers.html#avgpool',
                               'fastai.layers.BatchNorm': 'https://docs.fast.ai/layers.html#batchnorm',
                               'fastai.layers.BatchNorm1dFlat': 'https://docs.fast.ai/layers.html#batchnorm1dflat',
                               'fastai.layers.BatchNorm1dFlat.forward': 'https://docs.fast.ai/layers.html#batchnorm1dflat.forward',
                               'fastai.layers.Cat': 'https://docs.fast.ai/layers.html#cat',
                               'fastai.layers.Cat.forward': 'https://docs.fast.ai/layers.html#cat.forward',
                               'fastai.layers.ConvLayer': 'https://docs.fast.ai/layers.html#convlayer',
                               'fastai.layers.Debugger': 'https://docs.fast.ai/layers.html#debugger',
                               'fastai.layers.Embedding': 'https://docs.fast.ai/layers.html#embedding',
                               'fastai.layers.Flatten': 'https://docs.fast.ai/layers.html#flatten',
                               'fastai.layers.Identity': 'https://docs.fast.ai/layers.html#identity',
                               'fastai.layers.InstanceNorm': 'https://docs.fast.ai/layers.html#instancenorm',
                               'fastai.layers.Lambda': 'https://docs.fast.ai/layers.html#lambda',
                               'fastai.layers.LinBnDrop': 'https://docs.fast.ai/layers.html#linbndrop',
                               'fastai.layers.MaxPool': 'https://docs.fast.ai/layers.html#maxpool',
                               'fastai.layers.MergeLayer': 'https://docs.fast.ai/layers.html#mergelayer',
                               'fastai.layers.MergeLayer.forward': 'https://docs.fast.ai/layers.html#mergelayer.forward',
                               'fastai.layers.Mish': 'https://docs.fast.ai/layers.html#mish',
                               'fastai.layers.Mish.forward': 'https://docs.fast.ai/layers.html#mish.forward',
                               'fastai.layers.MishJitAutoFn': 'https://docs.fast.ai/layers.html#mishjitautofn',
                               'fastai.layers.MishJitAutoFn.backward': 'https://docs.fast.ai/layers.html#mishjitautofn.backward',
                               'fastai.layers.MishJitAutoFn.forward': 'https://docs.fast.ai/layers.html#mishjitautofn.forward',
                               'fastai.layers.NoneReduce': 'https://docs.fast.ai/layers.html#nonereduce',
                               'fastai.layers.NormType': 'https://docs.fast.ai/layers.html#normtype',
                               'fastai.layers.ParameterModule': 'https://docs.fast.ai/layers.html#parametermodule',
                               'fastai.layers.ParameterModule.forward': 'https://docs.fast.ai/layers.html#parametermodule.forward',
                               'fastai.layers.PartialLambda': 'https://docs.fast.ai/layers.html#partiallambda',
                               'fastai.layers.PartialLambda.forward': 'https://docs.fast.ai/layers.html#partiallambda.forward',
                               'fastai.layers.PixelShuffle_ICNR': 'https://docs.fast.ai/layers.html#pixelshuffle_icnr',
                               'fastai.layers.PoolFlatten': 'https://docs.fast.ai/layers.html#poolflatten',
                               'fastai.layers.PoolType': 'https://docs.fast.ai/layers.html#pooltype',
                               'fastai.layers.PooledSelfAttention2d': 'https://docs.fast.ai/layers.html#pooledselfattention2d',
                               'fastai.layers.PooledSelfAttention2d.forward': 'https://docs.fast.ai/layers.html#pooledselfattention2d.forward',
                               'fastai.layers.ProdLayer': 'https://docs.fast.ai/layers.html#prodlayer',
                               'fastai.layers.ProdLayer.forward': 'https://docs.fast.ai/layers.html#prodlayer.forward',
                               'fastai.layers.ResBlock': 'https://docs.fast.ai/layers.html#resblock',
                               'fastai.layers.ResBlock.forward': 'https://docs.fast.ai/layers.html#resblock.forward',
                               'fastai.layers.ResizeBatch': 'https://docs.fast.ai/layers.html#resizebatch',
                               'fastai.layers.ResizeBatch.forward': 'https://docs.fast.ai/layers.html#resizebatch.forward',
                               'fastai.layers.SEBlock': 'https://docs.fast.ai/layers.html#seblock',
                               'fastai.layers.SEModule': 'https://docs.fast.ai/layers.html#semodule',
                               'fastai.layers.SEResNeXtBlock': 'https://docs.fast.ai/layers.html#seresnextblock',
                               'fastai.layers.SelfAttention': 'https://docs.fast.ai/layers.html#selfattention',
                               'fastai.layers.SelfAttention.forward': 'https://docs.fast.ai/layers.html#selfattention.forward',
                               'fastai.layers.SeparableBlock': 'https://docs.fast.ai/layers.html#separableblock',
                               'fastai.layers.SequentialEx': 'https://docs.fast.ai/layers.html#sequentialex',
                               'fastai.layers.SequentialEx.append': 'https://docs.fast.ai/layers.html#sequentialex.append',
                               'fastai.layers.SequentialEx.extend': 'https://docs.fast.ai/layers.html#sequentialex.extend',
                               'fastai.layers.SequentialEx.forward': 'https://docs.fast.ai/layers.html#sequentialex.forward',
                               'fastai.layers.SequentialEx.insert': 'https://docs.fast.ai/layers.html#sequentialex.insert',
                               'fastai.layers.SigmoidRange': 'https://docs.fast.ai/layers.html#sigmoidrange',
                               'fastai.layers.SimpleCNN': 'https://docs.fast.ai/layers.html#simplecnn',
                               'fastai.layers.SimpleSelfAttention': 'https://docs.fast.ai/layers.html#simpleselfattention',
                               'fastai.layers.SimpleSelfAttention.forward': 'https://docs.fast.ai/layers.html#simpleselfattention.forward',
                               'fastai.layers.Swish': 'https://docs.fast.ai/layers.html#swish',
                               'fastai.layers.Swish.forward': 'https://docs.fast.ai/layers.html#swish.forward',
                               'fastai.layers.TimeDistributed': 'https://docs.fast.ai/layers.html#timedistributed',
                               'fastai.layers.TimeDistributed.format_output': 'https://docs.fast.ai/layers.html#timedistributed.format_output',
                               'fastai.layers.TimeDistributed.forward': 'https://docs.fast.ai/layers.html#timedistributed.forward',
                               'fastai.layers.TimeDistributed.low_mem_forward': 'https://docs.fast.ai/layers.html#timedistributed.low_mem_forward',
                               'fastai.layers.ToTensorBase': 'https://docs.fast.ai/layers.html#totensorbase',
                               'fastai.layers.View': 'https://docs.fast.ai/layers.html#view',
                               'fastai.layers.View.forward': 'https://docs.fast.ai/layers.html#view.forward',
                               'fastai.layers.adaptive_pool': 'https://docs.fast.ai/layers.html#adaptive_pool',
                               'fastai.layers.children_and_parameters': 'https://docs.fast.ai/layers.html#children_and_parameters',
                               'fastai.layers.flatten_model': 'https://docs.fast.ai/layers.html#flatten_model',
                               'fastai.layers.has_children': 'https://docs.fast.ai/layers.html#has_children',
                               'fastai.layers.icnr_init': 'https://docs.fast.ai/layers.html#icnr_init',
                               'fastai.layers.in_channels': 'https://docs.fast.ai/layers.html#in_channels',
                               'fastai.layers.init_default': 'https://docs.fast.ai/layers.html#init_default',
                               'fastai.layers.init_linear': 'https://docs.fast.ai/layers.html#init_linear',
                               'fastai.layers.inplace_relu': 'https://docs.fast.ai/layers.html#inplace_relu',
                               'fastai.layers.mish': 'https://docs.fast.ai/layers.html#mish',
                               'fastai.layers.module': 'https://docs.fast.ai/layers.html#module',
                               'fastai.layers.sequential': 'https://docs.fast.ai/layers.html#sequential',
                               'fastai.layers.sigmoid': 'https://docs.fast.ai/layers.html#sigmoid',
                               'fastai.layers.sigmoid_': 'https://docs.fast.ai/layers.html#sigmoid_',
                               'fastai.layers.sigmoid_range': 'https://docs.fast.ai/layers.html#sigmoid_range',
                               'fastai.layers.swish': 'https://docs.fast.ai/layers.html#swish',
                               'fastai.layers.trunc_normal_': 'https://docs.fast.ai/layers.html#trunc_normal_',
                               'fastai.layers.vleaky_relu': 'https://docs.fast.ai/layers.html#vleaky_relu'},
            'fastai.learner': { 'fastai.learner.AvgLoss': 'https://docs.fast.ai/learner.html#avgloss',
                                'fastai.learner.AvgLoss.accumulate': 'https://docs.fast.ai/learner.html#avgloss.accumulate',
                                'fastai.learner.AvgLoss.name': 'https://docs.fast.ai/learner.html#avgloss.name',
                                'fastai.learner.AvgLoss.reset': 'https://docs.fast.ai/learner.html#avgloss.reset',
                                'fastai.learner.AvgLoss.value': 'https://docs.fast.ai/learner.html#avgloss.value',
                                'fastai.learner.AvgMetric': 'https://docs.fast.ai/learner.html#avgmetric',
                                'fastai.learner.AvgMetric.accumulate': 'https://docs.fast.ai/learner.html#avgmetric.accumulate',
                                'fastai.learner.AvgMetric.name': 'https://docs.fast.ai/learner.html#avgmetric.name',
                                'fastai.learner.AvgMetric.reset': 'https://docs.fast.ai/learner.html#avgmetric.reset',
                                'fastai.learner.AvgMetric.value': 'https://docs.fast.ai/learner.html#avgmetric.value',
                                'fastai.learner.AvgSmoothLoss': 'https://docs.fast.ai/learner.html#avgsmoothloss',
                                'fastai.learner.AvgSmoothLoss.accumulate': 'https://docs.fast.ai/learner.html#avgsmoothloss.accumulate',
                                'fastai.learner.AvgSmoothLoss.reset': 'https://docs.fast.ai/learner.html#avgsmoothloss.reset',
                                'fastai.learner.AvgSmoothLoss.value': 'https://docs.fast.ai/learner.html#avgsmoothloss.value',
                                'fastai.learner.CancelBackwardException': 'https://docs.fast.ai/learner.html#cancelbackwardexception',
                                'fastai.learner.CancelBatchException': 'https://docs.fast.ai/learner.html#cancelbatchexception',
                                'fastai.learner.CancelEpochException': 'https://docs.fast.ai/learner.html#cancelepochexception',
                                'fastai.learner.CancelFitException': 'https://docs.fast.ai/learner.html#cancelfitexception',
                                'fastai.learner.CancelStepException': 'https://docs.fast.ai/learner.html#cancelstepexception',
                                'fastai.learner.CancelTrainException': 'https://docs.fast.ai/learner.html#canceltrainexception',
                                'fastai.learner.CancelValidException': 'https://docs.fast.ai/learner.html#cancelvalidexception',
                                'fastai.learner.CastToTensor': 'https://docs.fast.ai/learner.html#casttotensor',
                                'fastai.learner.CastToTensor.before_batch': 'https://docs.fast.ai/learner.html#casttotensor.before_batch',
                                'fastai.learner.Learner': 'https://docs.fast.ai/learner.html#learner',
                                'fastai.learner.Learner.add_cb': 'https://docs.fast.ai/learner.html#learner.add_cb',
                                'fastai.learner.Learner.add_cbs': 'https://docs.fast.ai/learner.html#learner.add_cbs',
                                'fastai.learner.Learner.added_cbs': 'https://docs.fast.ai/learner.html#learner.added_cbs',
                                'fastai.learner.Learner.all_batches': 'https://docs.fast.ai/learner.html#learner.all_batches',
                                'fastai.learner.Learner.create_opt': 'https://docs.fast.ai/learner.html#learner.create_opt',
                                'fastai.learner.Learner.export': 'https://docs.fast.ai/learner.html#learner.export',
                                'fastai.learner.Learner.fit': 'https://docs.fast.ai/learner.html#learner.fit',
                                'fastai.learner.Learner.freeze': 'https://docs.fast.ai/learner.html#learner.freeze',
                                'fastai.learner.Learner.freeze_to': 'https://docs.fast.ai/learner.html#learner.freeze_to',
                                'fastai.learner.Learner.get_preds': 'https://docs.fast.ai/learner.html#learner.get_preds',
                                'fastai.learner.Learner.load': 'https://docs.fast.ai/learner.html#learner.load',
                                'fastai.learner.Learner.loss_not_reduced': 'https://docs.fast.ai/learner.html#learner.loss_not_reduced',
                                'fastai.learner.Learner.metrics': 'https://docs.fast.ai/learner.html#learner.metrics',
                                'fastai.learner.Learner.no_logging': 'https://docs.fast.ai/learner.html#learner.no_logging',
                                'fastai.learner.Learner.no_mbar': 'https://docs.fast.ai/learner.html#learner.no_mbar',
                                'fastai.learner.Learner.one_batch': 'https://docs.fast.ai/learner.html#learner.one_batch',
                                'fastai.learner.Learner.ordered_cbs': 'https://docs.fast.ai/learner.html#learner.ordered_cbs',
                                'fastai.learner.Learner.predict': 'https://docs.fast.ai/learner.html#learner.predict',
                                'fastai.learner.Learner.remove_cb': 'https://docs.fast.ai/learner.html#learner.remove_cb',
                                'fastai.learner.Learner.remove_cbs': 'https://docs.fast.ai/learner.html#learner.remove_cbs',
                                'fastai.learner.Learner.removed_cbs': 'https://docs.fast.ai/learner.html#learner.removed_cbs',
                                'fastai.learner.Learner.save': 'https://docs.fast.ai/learner.html#learner.save',
                                'fastai.learner.Learner.show_results': 'https://docs.fast.ai/learner.html#learner.show_results',
                                'fastai.learner.Learner.show_training_loop': 'https://docs.fast.ai/learner.html#learner.show_training_loop',
                                'fastai.learner.Learner.to_detach': 'https://docs.fast.ai/learner.html#learner.to_detach',
                                'fastai.learner.Learner.tta': 'https://docs.fast.ai/learner.html#learner.tta',
                                'fastai.learner.Learner.unfreeze': 'https://docs.fast.ai/learner.html#learner.unfreeze',
                                'fastai.learner.Learner.validate': 'https://docs.fast.ai/learner.html#learner.validate',
                                'fastai.learner.Learner.validation_context': 'https://docs.fast.ai/learner.html#learner.validation_context',
                                'fastai.learner.Metric': 'https://docs.fast.ai/learner.html#metric',
                                'fastai.learner.Metric.accumulate': 'https://docs.fast.ai/learner.html#metric.accumulate',
                                'fastai.learner.Metric.name': 'https://docs.fast.ai/learner.html#metric.name',
                                'fastai.learner.Metric.reset': 'https://docs.fast.ai/learner.html#metric.reset',
                                'fastai.learner.Metric.value': 'https://docs.fast.ai/learner.html#metric.value',
                                'fastai.learner.Recorder': 'https://docs.fast.ai/learner.html#recorder',
                                'fastai.learner.Recorder.after_batch': 'https://docs.fast.ai/learner.html#recorder.after_batch',
                                'fastai.learner.Recorder.after_cancel_train': 'https://docs.fast.ai/learner.html#recorder.after_cancel_train',
                                'fastai.learner.Recorder.after_cancel_validate': 'https://docs.fast.ai/learner.html#recorder.after_cancel_validate',
                                'fastai.learner.Recorder.after_epoch': 'https://docs.fast.ai/learner.html#recorder.after_epoch',
                                'fastai.learner.Recorder.after_train': 'https://docs.fast.ai/learner.html#recorder.after_train',
                                'fastai.learner.Recorder.after_validate': 'https://docs.fast.ai/learner.html#recorder.after_validate',
                                'fastai.learner.Recorder.before_epoch': 'https://docs.fast.ai/learner.html#recorder.before_epoch',
                                'fastai.learner.Recorder.before_fit': 'https://docs.fast.ai/learner.html#recorder.before_fit',
                                'fastai.learner.Recorder.before_train': 'https://docs.fast.ai/learner.html#recorder.before_train',
                                'fastai.learner.Recorder.before_validate': 'https://docs.fast.ai/learner.html#recorder.before_validate',
                                'fastai.learner.Recorder.plot_loss': 'https://docs.fast.ai/learner.html#recorder.plot_loss',
                                'fastai.learner.SkipToEpoch': 'https://docs.fast.ai/learner.html#skiptoepoch',
                                'fastai.learner.SkipToEpoch.before_epoch': 'https://docs.fast.ai/learner.html#skiptoepoch.before_epoch',
                                'fastai.learner.ValueMetric': 'https://docs.fast.ai/learner.html#valuemetric',
                                'fastai.learner.ValueMetric.name': 'https://docs.fast.ai/learner.html#valuemetric.name',
                                'fastai.learner.ValueMetric.value': 'https://docs.fast.ai/learner.html#valuemetric.value',
                                'fastai.learner.before_batch_cb': 'https://docs.fast.ai/learner.html#before_batch_cb',
                                'fastai.learner.load_learner': 'https://docs.fast.ai/learner.html#load_learner',
                                'fastai.learner.load_model': 'https://docs.fast.ai/learner.html#load_model',
                                'fastai.learner.mk_metric': 'https://docs.fast.ai/learner.html#mk_metric',
                                'fastai.learner.replacing_yield': 'https://docs.fast.ai/learner.html#replacing_yield',
                                'fastai.learner.save_model': 'https://docs.fast.ai/learner.html#save_model'},
            'fastai.losses': { 'fastai.losses.BCELossFlat': 'https://docs.fast.ai/losses.html#bcelossflat',
                               'fastai.losses.BCEWithLogitsLossFlat': 'https://docs.fast.ai/losses.html#bcewithlogitslossflat',
                               'fastai.losses.BCEWithLogitsLossFlat.activation': 'https://docs.fast.ai/losses.html#bcewithlogitslossflat.activation',
                               'fastai.losses.BCEWithLogitsLossFlat.decodes': 'https://docs.fast.ai/losses.html#bcewithlogitslossflat.decodes',
                               'fastai.losses.BaseLoss': 'https://docs.fast.ai/losses.html#baseloss',
                               'fastai.losses.BaseLoss.reduction': 'https://docs.fast.ai/losses.html#baseloss.reduction',
                               'fastai.losses.BaseLoss.to': 'https://docs.fast.ai/losses.html#baseloss.to',
                               'fastai.losses.CrossEntropyLossFlat': 'https://docs.fast.ai/losses.html#crossentropylossflat',
                               'fastai.losses.CrossEntropyLossFlat.activation': 'https://docs.fast.ai/losses.html#crossentropylossflat.activation',
                               'fastai.losses.CrossEntropyLossFlat.decodes': 'https://docs.fast.ai/losses.html#crossentropylossflat.decodes',
                               'fastai.losses.DiceLoss': 'https://docs.fast.ai/losses.html#diceloss',
                               'fastai.losses.DiceLoss.activation': 'https://docs.fast.ai/losses.html#diceloss.activation',
                               'fastai.losses.DiceLoss.decodes': 'https://docs.fast.ai/losses.html#diceloss.decodes',
                               'fastai.losses.FocalLoss': 'https://docs.fast.ai/losses.html#focalloss',
                               'fastai.losses.FocalLoss.forward': 'https://docs.fast.ai/losses.html#focalloss.forward',
                               'fastai.losses.FocalLossFlat': 'https://docs.fast.ai/losses.html#focallossflat',
                               'fastai.losses.FocalLossFlat.activation': 'https://docs.fast.ai/losses.html#focallossflat.activation',
                               'fastai.losses.FocalLossFlat.decodes': 'https://docs.fast.ai/losses.html#focallossflat.decodes',
                               'fastai.losses.L1LossFlat': 'https://docs.fast.ai/losses.html#l1lossflat',
                               'fastai.losses.LabelSmoothingCrossEntropy': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropy',
                               'fastai.losses.LabelSmoothingCrossEntropy.activation': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropy.activation',
                               'fastai.losses.LabelSmoothingCrossEntropy.decodes': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropy.decodes',
                               'fastai.losses.LabelSmoothingCrossEntropy.forward': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropy.forward',
                               'fastai.losses.LabelSmoothingCrossEntropyFlat': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropyflat',
                               'fastai.losses.LabelSmoothingCrossEntropyFlat.activation': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropyflat.activation',
                               'fastai.losses.LabelSmoothingCrossEntropyFlat.decodes': 'https://docs.fast.ai/losses.html#labelsmoothingcrossentropyflat.decodes',
                               'fastai.losses.MSELossFlat': 'https://docs.fast.ai/losses.html#mselossflat'},
            'fastai.medical.imaging': { 'fastai.medical.imaging.DcmDataset': 'https://docs.fast.ai/medical.imaging.html#dcmdataset',
                                        'fastai.medical.imaging.DcmDataset.as_dict': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.as_dict',
                                        'fastai.medical.imaging.DcmDataset.hist_scaled': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.hist_scaled',
                                        'fastai.medical.imaging.DcmDataset.mask_from_blur': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.mask_from_blur',
                                        'fastai.medical.imaging.DcmDataset.pct_in_window': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.pct_in_window',
                                        'fastai.medical.imaging.DcmDataset.pixels': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.pixels',
                                        'fastai.medical.imaging.DcmDataset.save_jpg': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.save_jpg',
                                        'fastai.medical.imaging.DcmDataset.save_tif16': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.save_tif16',
                                        'fastai.medical.imaging.DcmDataset.scaled_px': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.scaled_px',
                                        'fastai.medical.imaging.DcmDataset.set_pixels': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.set_pixels',
                                        'fastai.medical.imaging.DcmDataset.shape': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.shape',
                                        'fastai.medical.imaging.DcmDataset.show': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.show',
                                        'fastai.medical.imaging.DcmDataset.to_3chan': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.to_3chan',
                                        'fastai.medical.imaging.DcmDataset.to_nchan': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.to_nchan',
                                        'fastai.medical.imaging.DcmDataset.to_uint16': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.to_uint16',
                                        'fastai.medical.imaging.DcmDataset.windowed': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.windowed',
                                        'fastai.medical.imaging.DcmDataset.zoom': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.zoom',
                                        'fastai.medical.imaging.DcmDataset.zoom_to': 'https://docs.fast.ai/medical.imaging.html#dcmdataset.zoom_to',
                                        'fastai.medical.imaging.DcmMultiValue': 'https://docs.fast.ai/medical.imaging.html#dcmmultivalue',
                                        'fastai.medical.imaging.DcmTag': 'https://docs.fast.ai/medical.imaging.html#dcmtag',
                                        'fastai.medical.imaging.DicomSegmentationDataLoaders': 'https://docs.fast.ai/medical.imaging.html#dicomsegmentationdataloaders',
                                        'fastai.medical.imaging.DicomSegmentationDataLoaders.from_label_func': 'https://docs.fast.ai/medical.imaging.html#dicomsegmentationdataloaders.from_label_func',
                                        'fastai.medical.imaging.PILCTScan': 'https://docs.fast.ai/medical.imaging.html#pilctscan',
                                        'fastai.medical.imaging.PILDicom': 'https://docs.fast.ai/medical.imaging.html#pildicom',
                                        'fastai.medical.imaging.PILDicom.create': 'https://docs.fast.ai/medical.imaging.html#pildicom.create',
                                        'fastai.medical.imaging.Path.dcmread': 'https://docs.fast.ai/medical.imaging.html#path.dcmread',
                                        'fastai.medical.imaging.Path.png16read': 'https://docs.fast.ai/medical.imaging.html#path.png16read',
                                        'fastai.medical.imaging.Tensor.freqhist_bins': 'https://docs.fast.ai/medical.imaging.html#tensor.freqhist_bins',
                                        'fastai.medical.imaging.Tensor.hist_scaled': 'https://docs.fast.ai/medical.imaging.html#tensor.hist_scaled',
                                        'fastai.medical.imaging.Tensor.hist_scaled_pt': 'https://docs.fast.ai/medical.imaging.html#tensor.hist_scaled_pt',
                                        'fastai.medical.imaging.Tensor.mask_from_blur': 'https://docs.fast.ai/medical.imaging.html#tensor.mask_from_blur',
                                        'fastai.medical.imaging.Tensor.save_jpg': 'https://docs.fast.ai/medical.imaging.html#tensor.save_jpg',
                                        'fastai.medical.imaging.Tensor.save_tif16': 'https://docs.fast.ai/medical.imaging.html#tensor.save_tif16',
                                        'fastai.medical.imaging.Tensor.to_3chan': 'https://docs.fast.ai/medical.imaging.html#tensor.to_3chan',
                                        'fastai.medical.imaging.Tensor.to_nchan': 'https://docs.fast.ai/medical.imaging.html#tensor.to_nchan',
                                        'fastai.medical.imaging.Tensor.to_uint16': 'https://docs.fast.ai/medical.imaging.html#tensor.to_uint16',
                                        'fastai.medical.imaging.Tensor.windowed': 'https://docs.fast.ai/medical.imaging.html#tensor.windowed',
                                        'fastai.medical.imaging.TensorCTScan': 'https://docs.fast.ai/medical.imaging.html#tensorctscan',
                                        'fastai.medical.imaging.TensorDicom': 'https://docs.fast.ai/medical.imaging.html#tensordicom',
                                        'fastai.medical.imaging.array_freqhist_bins': 'https://docs.fast.ai/medical.imaging.html#array_freqhist_bins',
                                        'fastai.medical.imaging.crop_resize': 'https://docs.fast.ai/medical.imaging.html#crop_resize',
                                        'fastai.medical.imaging.dcmread': 'https://docs.fast.ai/medical.imaging.html#dcmread',
                                        'fastai.medical.imaging.dicom_windows': 'https://docs.fast.ai/medical.imaging.html#dicom_windows',
                                        'fastai.medical.imaging.gauss_blur2d': 'https://docs.fast.ai/medical.imaging.html#gauss_blur2d',
                                        'fastai.medical.imaging.get_dicom_files': 'https://docs.fast.ai/medical.imaging.html#get_dicom_files',
                                        'fastai.medical.imaging.mask2bbox': 'https://docs.fast.ai/medical.imaging.html#mask2bbox',
                                        'fastai.medical.imaging.uniform_blur2d': 'https://docs.fast.ai/medical.imaging.html#uniform_blur2d'},
            'fastai.medical.text': {},
            'fastai.metrics': { 'fastai.metrics.APScoreBinary': 'https://docs.fast.ai/metrics.html#apscorebinary',
                                'fastai.metrics.APScoreMulti': 'https://docs.fast.ai/metrics.html#apscoremulti',
                                'fastai.metrics.AccumMetric': 'https://docs.fast.ai/metrics.html#accummetric',
                                'fastai.metrics.AccumMetric.accum_values': 'https://docs.fast.ai/metrics.html#accummetric.accum_values',
                                'fastai.metrics.AccumMetric.accumulate': 'https://docs.fast.ai/metrics.html#accummetric.accumulate',
                                'fastai.metrics.AccumMetric.name': 'https://docs.fast.ai/metrics.html#accummetric.name',
                                'fastai.metrics.AccumMetric.reset': 'https://docs.fast.ai/metrics.html#accummetric.reset',
                                'fastai.metrics.AccumMetric.value': 'https://docs.fast.ai/metrics.html#accummetric.value',
                                'fastai.metrics.BalancedAccuracy': 'https://docs.fast.ai/metrics.html#balancedaccuracy',
                                'fastai.metrics.BrierScore': 'https://docs.fast.ai/metrics.html#brierscore',
                                'fastai.metrics.BrierScoreMulti': 'https://docs.fast.ai/metrics.html#brierscoremulti',
                                'fastai.metrics.CohenKappa': 'https://docs.fast.ai/metrics.html#cohenkappa',
                                'fastai.metrics.CorpusBLEUMetric': 'https://docs.fast.ai/metrics.html#corpusbleumetric',
                                'fastai.metrics.CorpusBLEUMetric.accumulate': 'https://docs.fast.ai/metrics.html#corpusbleumetric.accumulate',
                                'fastai.metrics.CorpusBLEUMetric.get_correct_ngrams': 'https://docs.fast.ai/metrics.html#corpusbleumetric.get_correct_ngrams',
                                'fastai.metrics.CorpusBLEUMetric.get_grams': 'https://docs.fast.ai/metrics.html#corpusbleumetric.get_grams',
                                'fastai.metrics.CorpusBLEUMetric.reset': 'https://docs.fast.ai/metrics.html#corpusbleumetric.reset',
                                'fastai.metrics.CorpusBLEUMetric.value': 'https://docs.fast.ai/metrics.html#corpusbleumetric.value',
                                'fastai.metrics.Dice': 'https://docs.fast.ai/metrics.html#dice',
                                'fastai.metrics.Dice.accumulate': 'https://docs.fast.ai/metrics.html#dice.accumulate',
                                'fastai.metrics.Dice.reset': 'https://docs.fast.ai/metrics.html#dice.reset',
                                'fastai.metrics.Dice.value': 'https://docs.fast.ai/metrics.html#dice.value',
                                'fastai.metrics.DiceMulti': 'https://docs.fast.ai/metrics.html#dicemulti',
                                'fastai.metrics.DiceMulti.accumulate': 'https://docs.fast.ai/metrics.html#dicemulti.accumulate',
                                'fastai.metrics.DiceMulti.reset': 'https://docs.fast.ai/metrics.html#dicemulti.reset',
                                'fastai.metrics.DiceMulti.value': 'https://docs.fast.ai/metrics.html#dicemulti.value',
                                'fastai.metrics.ExplainedVariance': 'https://docs.fast.ai/metrics.html#explainedvariance',
                                'fastai.metrics.F1Score': 'https://docs.fast.ai/metrics.html#f1score',
                                'fastai.metrics.F1ScoreMulti': 'https://docs.fast.ai/metrics.html#f1scoremulti',
                                'fastai.metrics.FBeta': 'https://docs.fast.ai/metrics.html#fbeta',
                                'fastai.metrics.FBetaMulti': 'https://docs.fast.ai/metrics.html#fbetamulti',
                                'fastai.metrics.HammingLoss': 'https://docs.fast.ai/metrics.html#hammingloss',
                                'fastai.metrics.HammingLossMulti': 'https://docs.fast.ai/metrics.html#hamminglossmulti',
                                'fastai.metrics.Jaccard': 'https://docs.fast.ai/metrics.html#jaccard',
                                'fastai.metrics.JaccardCoeff': 'https://docs.fast.ai/metrics.html#jaccardcoeff',
                                'fastai.metrics.JaccardCoeff.value': 'https://docs.fast.ai/metrics.html#jaccardcoeff.value',
                                'fastai.metrics.JaccardMulti': 'https://docs.fast.ai/metrics.html#jaccardmulti',
                                'fastai.metrics.LossMetric': 'https://docs.fast.ai/metrics.html#lossmetric',
                                'fastai.metrics.LossMetric.accumulate': 'https://docs.fast.ai/metrics.html#lossmetric.accumulate',
                                'fastai.metrics.LossMetric.name': 'https://docs.fast.ai/metrics.html#lossmetric.name',
                                'fastai.metrics.LossMetrics': 'https://docs.fast.ai/metrics.html#lossmetrics',
                                'fastai.metrics.MatthewsCorrCoef': 'https://docs.fast.ai/metrics.html#matthewscorrcoef',
                                'fastai.metrics.MatthewsCorrCoefMulti': 'https://docs.fast.ai/metrics.html#matthewscorrcoefmulti',
                                'fastai.metrics.PearsonCorrCoef': 'https://docs.fast.ai/metrics.html#pearsoncorrcoef',
                                'fastai.metrics.Perplexity': 'https://docs.fast.ai/metrics.html#perplexity',
                                'fastai.metrics.Perplexity.name': 'https://docs.fast.ai/metrics.html#perplexity.name',
                                'fastai.metrics.Perplexity.value': 'https://docs.fast.ai/metrics.html#perplexity.value',
                                'fastai.metrics.Precision': 'https://docs.fast.ai/metrics.html#precision',
                                'fastai.metrics.PrecisionMulti': 'https://docs.fast.ai/metrics.html#precisionmulti',
                                'fastai.metrics.R2Score': 'https://docs.fast.ai/metrics.html#r2score',
                                'fastai.metrics.Recall': 'https://docs.fast.ai/metrics.html#recall',
                                'fastai.metrics.RecallMulti': 'https://docs.fast.ai/metrics.html#recallmulti',
                                'fastai.metrics.RocAuc': 'https://docs.fast.ai/metrics.html#rocauc',
                                'fastai.metrics.RocAucBinary': 'https://docs.fast.ai/metrics.html#rocaucbinary',
                                'fastai.metrics.RocAucMulti': 'https://docs.fast.ai/metrics.html#rocaucmulti',
                                'fastai.metrics.SpearmanCorrCoef': 'https://docs.fast.ai/metrics.html#spearmancorrcoef',
                                'fastai.metrics.accuracy': 'https://docs.fast.ai/metrics.html#accuracy',
                                'fastai.metrics.accuracy_multi': 'https://docs.fast.ai/metrics.html#accuracy_multi',
                                'fastai.metrics.error_rate': 'https://docs.fast.ai/metrics.html#error_rate',
                                'fastai.metrics.exp_rmspe': 'https://docs.fast.ai/metrics.html#exp_rmspe',
                                'fastai.metrics.foreground_acc': 'https://docs.fast.ai/metrics.html#foreground_acc',
                                'fastai.metrics.mae': 'https://docs.fast.ai/metrics.html#mae',
                                'fastai.metrics.mse': 'https://docs.fast.ai/metrics.html#mse',
                                'fastai.metrics.msle': 'https://docs.fast.ai/metrics.html#msle',
                                'fastai.metrics.optim_metric': 'https://docs.fast.ai/metrics.html#optim_metric',
                                'fastai.metrics.perplexity': 'https://docs.fast.ai/metrics.html#perplexity',
                                'fastai.metrics.rmse': 'https://docs.fast.ai/metrics.html#rmse',
                                'fastai.metrics.skm_to_fastai': 'https://docs.fast.ai/metrics.html#skm_to_fastai',
                                'fastai.metrics.top_k_accuracy': 'https://docs.fast.ai/metrics.html#top_k_accuracy'},
            'fastai.optimizer': { 'fastai.optimizer.Adam': 'https://docs.fast.ai/optimizer.html#adam',
                                  'fastai.optimizer.Lamb': 'https://docs.fast.ai/optimizer.html#lamb',
                                  'fastai.optimizer.Larc': 'https://docs.fast.ai/optimizer.html#larc',
                                  'fastai.optimizer.Lookahead': 'https://docs.fast.ai/optimizer.html#lookahead',
                                  'fastai.optimizer.Lookahead.clear_state': 'https://docs.fast.ai/optimizer.html#lookahead.clear_state',
                                  'fastai.optimizer.Lookahead.load_state_dict': 'https://docs.fast.ai/optimizer.html#lookahead.load_state_dict',
                                  'fastai.optimizer.Lookahead.param_lists': 'https://docs.fast.ai/optimizer.html#lookahead.param_lists',
                                  'fastai.optimizer.Lookahead.state_dict': 'https://docs.fast.ai/optimizer.html#lookahead.state_dict',
                                  'fastai.optimizer.Lookahead.step': 'https://docs.fast.ai/optimizer.html#lookahead.step',
                                  'fastai.optimizer.OptimWrapper': 'https://docs.fast.ai/optimizer.html#optimwrapper',
                                  'fastai.optimizer.OptimWrapper.clear_state': 'https://docs.fast.ai/optimizer.html#optimwrapper.clear_state',
                                  'fastai.optimizer.OptimWrapper.hypers': 'https://docs.fast.ai/optimizer.html#optimwrapper.hypers',
                                  'fastai.optimizer.OptimWrapper.param_lists': 'https://docs.fast.ai/optimizer.html#optimwrapper.param_lists',
                                  'fastai.optimizer.Optimizer': 'https://docs.fast.ai/optimizer.html#optimizer',
                                  'fastai.optimizer.Optimizer.clear_state': 'https://docs.fast.ai/optimizer.html#optimizer.clear_state',
                                  'fastai.optimizer.Optimizer.load_state_dict': 'https://docs.fast.ai/optimizer.html#optimizer.load_state_dict',
                                  'fastai.optimizer.Optimizer.state_dict': 'https://docs.fast.ai/optimizer.html#optimizer.state_dict',
                                  'fastai.optimizer.Optimizer.step': 'https://docs.fast.ai/optimizer.html#optimizer.step',
                                  'fastai.optimizer.Optimizer.zero_grad': 'https://docs.fast.ai/optimizer.html#optimizer.zero_grad',
                                  'fastai.optimizer.QHAdam': 'https://docs.fast.ai/optimizer.html#qhadam',
                                  'fastai.optimizer.RAdam': 'https://docs.fast.ai/optimizer.html#radam',
                                  'fastai.optimizer.RMSProp': 'https://docs.fast.ai/optimizer.html#rmsprop',
                                  'fastai.optimizer.SGD': 'https://docs.fast.ai/optimizer.html#sgd',
                                  'fastai.optimizer.adam_step': 'https://docs.fast.ai/optimizer.html#adam_step',
                                  'fastai.optimizer.average_grad': 'https://docs.fast.ai/optimizer.html#average_grad',
                                  'fastai.optimizer.average_sqr_grad': 'https://docs.fast.ai/optimizer.html#average_sqr_grad',
                                  'fastai.optimizer.debias': 'https://docs.fast.ai/optimizer.html#debias',
                                  'fastai.optimizer.detuplify_pg': 'https://docs.fast.ai/optimizer.html#detuplify_pg',
                                  'fastai.optimizer.l2_reg': 'https://docs.fast.ai/optimizer.html#l2_reg',
                                  'fastai.optimizer.lamb_step': 'https://docs.fast.ai/optimizer.html#lamb_step',
                                  'fastai.optimizer.larc_layer_lr': 'https://docs.fast.ai/optimizer.html#larc_layer_lr',
                                  'fastai.optimizer.larc_step': 'https://docs.fast.ai/optimizer.html#larc_step',
                                  'fastai.optimizer.momentum_step': 'https://docs.fast.ai/optimizer.html#momentum_step',
                                  'fastai.optimizer.pytorch_hp_map': 'https://docs.fast.ai/optimizer.html#pytorch_hp_map',
                                  'fastai.optimizer.qhadam_step': 'https://docs.fast.ai/optimizer.html#qhadam_step',
                                  'fastai.optimizer.radam_step': 'https://docs.fast.ai/optimizer.html#radam_step',
                                  'fastai.optimizer.ranger': 'https://docs.fast.ai/optimizer.html#ranger',
                                  'fastai.optimizer.rms_prop_step': 'https://docs.fast.ai/optimizer.html#rms_prop_step',
                                  'fastai.optimizer.set_item_pg': 'https://docs.fast.ai/optimizer.html#set_item_pg',
                                  'fastai.optimizer.sgd_step': 'https://docs.fast.ai/optimizer.html#sgd_step',
                                  'fastai.optimizer.step_stat': 'https://docs.fast.ai/optimizer.html#step_stat',
                                  'fastai.optimizer.weight_decay': 'https://docs.fast.ai/optimizer.html#weight_decay'},
            'fastai.tabular.all': {},
            'fastai.tabular.core': { 'fastai.tabular.core.Categorify': 'https://docs.fast.ai/tabular.core.html#categorify',
                                     'fastai.tabular.core.Categorify.decodes': 'https://docs.fast.ai/tabular.core.html#categorify.decodes',
                                     'fastai.tabular.core.Categorify.encodes': 'https://docs.fast.ai/tabular.core.html#categorify.encodes',
                                     'fastai.tabular.core.Categorify.setups': 'https://docs.fast.ai/tabular.core.html#categorify.setups',
                                     'fastai.tabular.core.FillMissing': 'https://docs.fast.ai/tabular.core.html#fillmissing',
                                     'fastai.tabular.core.FillMissing.encodes': 'https://docs.fast.ai/tabular.core.html#fillmissing.encodes',
                                     'fastai.tabular.core.FillMissing.setups': 'https://docs.fast.ai/tabular.core.html#fillmissing.setups',
                                     'fastai.tabular.core.FillStrategy': 'https://docs.fast.ai/tabular.core.html#fillstrategy',
                                     'fastai.tabular.core.FillStrategy.constant': 'https://docs.fast.ai/tabular.core.html#fillstrategy.constant',
                                     'fastai.tabular.core.FillStrategy.median': 'https://docs.fast.ai/tabular.core.html#fillstrategy.median',
                                     'fastai.tabular.core.FillStrategy.mode': 'https://docs.fast.ai/tabular.core.html#fillstrategy.mode',
                                     'fastai.tabular.core.ReadTabBatch': 'https://docs.fast.ai/tabular.core.html#readtabbatch',
                                     'fastai.tabular.core.ReadTabBatch.decodes': 'https://docs.fast.ai/tabular.core.html#readtabbatch.decodes',
                                     'fastai.tabular.core.ReadTabBatch.encodes': 'https://docs.fast.ai/tabular.core.html#readtabbatch.encodes',
                                     'fastai.tabular.core.TabDataLoader': 'https://docs.fast.ai/tabular.core.html#tabdataloader',
                                     'fastai.tabular.core.TabDataLoader.create_batch': 'https://docs.fast.ai/tabular.core.html#tabdataloader.create_batch',
                                     'fastai.tabular.core.TabDataLoader.do_item': 'https://docs.fast.ai/tabular.core.html#tabdataloader.do_item',
                                     'fastai.tabular.core.Tabular': 'https://docs.fast.ai/tabular.core.html#tabular',
                                     'fastai.tabular.core.Tabular.all_col_names': 'https://docs.fast.ai/tabular.core.html#tabular.all_col_names',
                                     'fastai.tabular.core.Tabular.copy': 'https://docs.fast.ai/tabular.core.html#tabular.copy',
                                     'fastai.tabular.core.Tabular.decode': 'https://docs.fast.ai/tabular.core.html#tabular.decode',
                                     'fastai.tabular.core.Tabular.decode_row': 'https://docs.fast.ai/tabular.core.html#tabular.decode_row',
                                     'fastai.tabular.core.Tabular.iloc': 'https://docs.fast.ai/tabular.core.html#tabular.iloc',
                                     'fastai.tabular.core.Tabular.loc': 'https://docs.fast.ai/tabular.core.html#tabular.loc',
                                     'fastai.tabular.core.Tabular.n_subsets': 'https://docs.fast.ai/tabular.core.html#tabular.n_subsets',
                                     'fastai.tabular.core.Tabular.new': 'https://docs.fast.ai/tabular.core.html#tabular.new',
                                     'fastai.tabular.core.Tabular.new_empty': 'https://docs.fast.ai/tabular.core.html#tabular.new_empty',
                                     'fastai.tabular.core.Tabular.process': 'https://docs.fast.ai/tabular.core.html#tabular.process',
                                     'fastai.tabular.core.Tabular.setup': 'https://docs.fast.ai/tabular.core.html#tabular.setup',
                                     'fastai.tabular.core.Tabular.show': 'https://docs.fast.ai/tabular.core.html#tabular.show',
                                     'fastai.tabular.core.Tabular.subset': 'https://docs.fast.ai/tabular.core.html#tabular.subset',
                                     'fastai.tabular.core.Tabular.targ': 'https://docs.fast.ai/tabular.core.html#tabular.targ',
                                     'fastai.tabular.core.Tabular.to_device': 'https://docs.fast.ai/tabular.core.html#tabular.to_device',
                                     'fastai.tabular.core.Tabular.x_names': 'https://docs.fast.ai/tabular.core.html#tabular.x_names',
                                     'fastai.tabular.core.Tabular.y': 'https://docs.fast.ai/tabular.core.html#tabular.y',
                                     'fastai.tabular.core.TabularPandas': 'https://docs.fast.ai/tabular.core.html#tabularpandas',
                                     'fastai.tabular.core.TabularPandas.transform': 'https://docs.fast.ai/tabular.core.html#tabularpandas.transform',
                                     'fastai.tabular.core.TabularProc': 'https://docs.fast.ai/tabular.core.html#tabularproc',
                                     'fastai.tabular.core.TabularProc.name': 'https://docs.fast.ai/tabular.core.html#tabularproc.name',
                                     'fastai.tabular.core.TabularProc.setup': 'https://docs.fast.ai/tabular.core.html#tabularproc.setup',
                                     'fastai.tabular.core.add_datepart': 'https://docs.fast.ai/tabular.core.html#add_datepart',
                                     'fastai.tabular.core.add_elapsed_times': 'https://docs.fast.ai/tabular.core.html#add_elapsed_times',
                                     'fastai.tabular.core.cont_cat_split': 'https://docs.fast.ai/tabular.core.html#cont_cat_split',
                                     'fastai.tabular.core.df_shrink': 'https://docs.fast.ai/tabular.core.html#df_shrink',
                                     'fastai.tabular.core.df_shrink_dtypes': 'https://docs.fast.ai/tabular.core.html#df_shrink_dtypes',
                                     'fastai.tabular.core.make_date': 'https://docs.fast.ai/tabular.core.html#make_date',
                                     'fastai.tabular.core.show_batch': 'https://docs.fast.ai/tabular.core.html#show_batch'},
            'fastai.tabular.data': { 'fastai.tabular.data.TabularDataLoaders': 'https://docs.fast.ai/tabular.data.html#tabulardataloaders',
                                     'fastai.tabular.data.TabularDataLoaders.from_csv': 'https://docs.fast.ai/tabular.data.html#tabulardataloaders.from_csv',
                                     'fastai.tabular.data.TabularDataLoaders.from_df': 'https://docs.fast.ai/tabular.data.html#tabulardataloaders.from_df',
                                     'fastai.tabular.data.TabularDataLoaders.test_dl': 'https://docs.fast.ai/tabular.data.html#tabulardataloaders.test_dl'},
            'fastai.tabular.learner': { 'fastai.tabular.learner.TabularLearner': 'https://docs.fast.ai/tabular.learner.html#tabularlearner',
                                        'fastai.tabular.learner.TabularLearner.predict': 'https://docs.fast.ai/tabular.learner.html#tabularlearner.predict',
                                        'fastai.tabular.learner.show_results': 'https://docs.fast.ai/tabular.learner.html#show_results',
                                        'fastai.tabular.learner.tabular_learner': 'https://docs.fast.ai/tabular.learner.html#tabular_learner'},
            'fastai.tabular.model': { 'fastai.tabular.model.TabularModel': 'https://docs.fast.ai/tabular.model.html#tabularmodel',
                                      'fastai.tabular.model.TabularModel.forward': 'https://docs.fast.ai/tabular.model.html#tabularmodel.forward',
                                      'fastai.tabular.model.emb_sz_rule': 'https://docs.fast.ai/tabular.model.html#emb_sz_rule',
                                      'fastai.tabular.model.get_emb_sz': 'https://docs.fast.ai/tabular.model.html#get_emb_sz',
                                      'fastai.tabular.model.tabular_config': 'https://docs.fast.ai/tabular.model.html#tabular_config'},
            'fastai.test_utils': { 'fastai.test_utils.RegModel': 'https://docs.fast.ai/test_utils.html#regmodel',
                                   'fastai.test_utils.RegModel.forward': 'https://docs.fast.ai/test_utils.html#regmodel.forward',
                                   'fastai.test_utils.VerboseCallback': 'https://docs.fast.ai/test_utils.html#verbosecallback',
                                   'fastai.test_utils.get_env': 'https://docs.fast.ai/test_utils.html#get_env',
                                   'fastai.test_utils.nvidia_mem': 'https://docs.fast.ai/test_utils.html#nvidia_mem',
                                   'fastai.test_utils.nvidia_smi': 'https://docs.fast.ai/test_utils.html#nvidia_smi',
                                   'fastai.test_utils.show_install': 'https://docs.fast.ai/test_utils.html#show_install',
                                   'fastai.test_utils.synth_dbunch': 'https://docs.fast.ai/test_utils.html#synth_dbunch',
                                   'fastai.test_utils.synth_learner': 'https://docs.fast.ai/test_utils.html#synth_learner',
                                   'fastai.test_utils.try_import': 'https://docs.fast.ai/test_utils.html#try_import'},
            'fastai.text.all': {},
            'fastai.text.core': { 'fastai.text.core.BOS': 'https://docs.fast.ai/text.core.html#bos',
                                  'fastai.text.core.BaseTokenizer': 'https://docs.fast.ai/text.core.html#basetokenizer',
                                  'fastai.text.core.EOS': 'https://docs.fast.ai/text.core.html#eos',
                                  'fastai.text.core.FLD': 'https://docs.fast.ai/text.core.html#fld',
                                  'fastai.text.core.PAD': 'https://docs.fast.ai/text.core.html#pad',
                                  'fastai.text.core.SentencePieceTokenizer': 'https://docs.fast.ai/text.core.html#sentencepiecetokenizer',
                                  'fastai.text.core.SentencePieceTokenizer.setup': 'https://docs.fast.ai/text.core.html#sentencepiecetokenizer.setup',
                                  'fastai.text.core.SentencePieceTokenizer.train': 'https://docs.fast.ai/text.core.html#sentencepiecetokenizer.train',
                                  'fastai.text.core.SpacyTokenizer': 'https://docs.fast.ai/text.core.html#spacytokenizer',
                                  'fastai.text.core.SubwordTokenizer': 'https://docs.fast.ai/text.core.html#subwordtokenizer',
                                  'fastai.text.core.TK_MAJ': 'https://docs.fast.ai/text.core.html#tk_maj',
                                  'fastai.text.core.TK_REP': 'https://docs.fast.ai/text.core.html#tk_rep',
                                  'fastai.text.core.TK_UP': 'https://docs.fast.ai/text.core.html#tk_up',
                                  'fastai.text.core.TK_WREP': 'https://docs.fast.ai/text.core.html#tk_wrep',
                                  'fastai.text.core.TokenizeWithRules': 'https://docs.fast.ai/text.core.html#tokenizewithrules',
                                  'fastai.text.core.Tokenizer': 'https://docs.fast.ai/text.core.html#tokenizer',
                                  'fastai.text.core.Tokenizer.decodes': 'https://docs.fast.ai/text.core.html#tokenizer.decodes',
                                  'fastai.text.core.Tokenizer.encodes': 'https://docs.fast.ai/text.core.html#tokenizer.encodes',
                                  'fastai.text.core.Tokenizer.from_df': 'https://docs.fast.ai/text.core.html#tokenizer.from_df',
                                  'fastai.text.core.Tokenizer.from_folder': 'https://docs.fast.ai/text.core.html#tokenizer.from_folder',
                                  'fastai.text.core.Tokenizer.get_lengths': 'https://docs.fast.ai/text.core.html#tokenizer.get_lengths',
                                  'fastai.text.core.Tokenizer.setups': 'https://docs.fast.ai/text.core.html#tokenizer.setups',
                                  'fastai.text.core.UNK': 'https://docs.fast.ai/text.core.html#unk',
                                  'fastai.text.core.WordTokenizer': 'https://docs.fast.ai/text.core.html#wordtokenizer',
                                  'fastai.text.core.eu_langs': 'https://docs.fast.ai/text.core.html#eu_langs',
                                  'fastai.text.core.fix_html': 'https://docs.fast.ai/text.core.html#fix_html',
                                  'fastai.text.core.fn_counter_pkl': 'https://docs.fast.ai/text.core.html#fn_counter_pkl',
                                  'fastai.text.core.fn_lengths_pkl': 'https://docs.fast.ai/text.core.html#fn_lengths_pkl',
                                  'fastai.text.core.load_tokenized_csv': 'https://docs.fast.ai/text.core.html#load_tokenized_csv',
                                  'fastai.text.core.lowercase': 'https://docs.fast.ai/text.core.html#lowercase',
                                  'fastai.text.core.parallel_tokenize': 'https://docs.fast.ai/text.core.html#parallel_tokenize',
                                  'fastai.text.core.replace_all_caps': 'https://docs.fast.ai/text.core.html#replace_all_caps',
                                  'fastai.text.core.replace_maj': 'https://docs.fast.ai/text.core.html#replace_maj',
                                  'fastai.text.core.replace_rep': 'https://docs.fast.ai/text.core.html#replace_rep',
                                  'fastai.text.core.replace_space': 'https://docs.fast.ai/text.core.html#replace_space',
                                  'fastai.text.core.replace_wrep': 'https://docs.fast.ai/text.core.html#replace_wrep',
                                  'fastai.text.core.rm_useless_spaces': 'https://docs.fast.ai/text.core.html#rm_useless_spaces',
                                  'fastai.text.core.spec_add_spaces': 'https://docs.fast.ai/text.core.html#spec_add_spaces',
                                  'fastai.text.core.tokenize1': 'https://docs.fast.ai/text.core.html#tokenize1',
                                  'fastai.text.core.tokenize_csv': 'https://docs.fast.ai/text.core.html#tokenize_csv',
                                  'fastai.text.core.tokenize_df': 'https://docs.fast.ai/text.core.html#tokenize_df',
                                  'fastai.text.core.tokenize_files': 'https://docs.fast.ai/text.core.html#tokenize_files',
                                  'fastai.text.core.tokenize_folder': 'https://docs.fast.ai/text.core.html#tokenize_folder',
                                  'fastai.text.core.tokenize_texts': 'https://docs.fast.ai/text.core.html#tokenize_texts'},
            'fastai.text.data': { 'fastai.text.data.LMDataLoader': 'https://docs.fast.ai/text.data.html#lmdataloader',
                                  'fastai.text.data.LMDataLoader.create_item': 'https://docs.fast.ai/text.data.html#lmdataloader.create_item',
                                  'fastai.text.data.LMDataLoader.make_chunks': 'https://docs.fast.ai/text.data.html#lmdataloader.make_chunks',
                                  'fastai.text.data.LMDataLoader.new': 'https://docs.fast.ai/text.data.html#lmdataloader.new',
                                  'fastai.text.data.LMDataLoader.shuffle_fn': 'https://docs.fast.ai/text.data.html#lmdataloader.shuffle_fn',
                                  'fastai.text.data.LMTensorText': 'https://docs.fast.ai/text.data.html#lmtensortext',
                                  'fastai.text.data.Numericalize': 'https://docs.fast.ai/text.data.html#numericalize',
                                  'fastai.text.data.Numericalize.decodes': 'https://docs.fast.ai/text.data.html#numericalize.decodes',
                                  'fastai.text.data.Numericalize.encodes': 'https://docs.fast.ai/text.data.html#numericalize.encodes',
                                  'fastai.text.data.Numericalize.setups': 'https://docs.fast.ai/text.data.html#numericalize.setups',
                                  'fastai.text.data.Pad_Chunk': 'https://docs.fast.ai/text.data.html#pad_chunk',
                                  'fastai.text.data.Pad_Chunk.before_call': 'https://docs.fast.ai/text.data.html#pad_chunk.before_call',
                                  'fastai.text.data.Pad_Chunk.decodes': 'https://docs.fast.ai/text.data.html#pad_chunk.decodes',
                                  'fastai.text.data.Pad_Chunk.encodes': 'https://docs.fast.ai/text.data.html#pad_chunk.encodes',
                                  'fastai.text.data.Pad_Input': 'https://docs.fast.ai/text.data.html#pad_input',
                                  'fastai.text.data.Pad_Input.decodes': 'https://docs.fast.ai/text.data.html#pad_input.decodes',
                                  'fastai.text.data.Pad_Input.encodes': 'https://docs.fast.ai/text.data.html#pad_input.encodes',
                                  'fastai.text.data.SortedDL': 'https://docs.fast.ai/text.data.html#sorteddl',
                                  'fastai.text.data.SortedDL.get_idxs': 'https://docs.fast.ai/text.data.html#sorteddl.get_idxs',
                                  'fastai.text.data.SortedDL.new': 'https://docs.fast.ai/text.data.html#sorteddl.new',
                                  'fastai.text.data.SortedDL.shuffle_fn': 'https://docs.fast.ai/text.data.html#sorteddl.shuffle_fn',
                                  'fastai.text.data.TensorText': 'https://docs.fast.ai/text.data.html#tensortext',
                                  'fastai.text.data.TextBlock': 'https://docs.fast.ai/text.data.html#textblock',
                                  'fastai.text.data.TextBlock.from_df': 'https://docs.fast.ai/text.data.html#textblock.from_df',
                                  'fastai.text.data.TextBlock.from_folder': 'https://docs.fast.ai/text.data.html#textblock.from_folder',
                                  'fastai.text.data.TextDataLoaders': 'https://docs.fast.ai/text.data.html#textdataloaders',
                                  'fastai.text.data.TextDataLoaders.from_csv': 'https://docs.fast.ai/text.data.html#textdataloaders.from_csv',
                                  'fastai.text.data.TextDataLoaders.from_df': 'https://docs.fast.ai/text.data.html#textdataloaders.from_df',
                                  'fastai.text.data.TextDataLoaders.from_folder': 'https://docs.fast.ai/text.data.html#textdataloaders.from_folder',
                                  'fastai.text.data.make_vocab': 'https://docs.fast.ai/text.data.html#make_vocab',
                                  'fastai.text.data.pad_chunk': 'https://docs.fast.ai/text.data.html#pad_chunk',
                                  'fastai.text.data.pad_input': 'https://docs.fast.ai/text.data.html#pad_input',
                                  'fastai.text.data.pad_input_chunk': 'https://docs.fast.ai/text.data.html#pad_input_chunk',
                                  'fastai.text.data.reverse_text': 'https://docs.fast.ai/text.data.html#reverse_text',
                                  'fastai.text.data.show_batch': 'https://docs.fast.ai/text.data.html#show_batch'},
            'fastai.text.learner': { 'fastai.text.learner.LMLearner': 'https://docs.fast.ai/text.learner.html#lmlearner',
                                     'fastai.text.learner.LMLearner.get_preds': 'https://docs.fast.ai/text.learner.html#lmlearner.get_preds',
                                     'fastai.text.learner.LMLearner.predict': 'https://docs.fast.ai/text.learner.html#lmlearner.predict',
                                     'fastai.text.learner.TextLearner': 'https://docs.fast.ai/text.learner.html#textlearner',
                                     'fastai.text.learner.TextLearner.load': 'https://docs.fast.ai/text.learner.html#textlearner.load',
                                     'fastai.text.learner.TextLearner.load_encoder': 'https://docs.fast.ai/text.learner.html#textlearner.load_encoder',
                                     'fastai.text.learner.TextLearner.load_pretrained': 'https://docs.fast.ai/text.learner.html#textlearner.load_pretrained',
                                     'fastai.text.learner.TextLearner.save_encoder': 'https://docs.fast.ai/text.learner.html#textlearner.save_encoder',
                                     'fastai.text.learner.clean_raw_keys': 'https://docs.fast.ai/text.learner.html#clean_raw_keys',
                                     'fastai.text.learner.decode_spec_tokens': 'https://docs.fast.ai/text.learner.html#decode_spec_tokens',
                                     'fastai.text.learner.language_model_learner': 'https://docs.fast.ai/text.learner.html#language_model_learner',
                                     'fastai.text.learner.load_ignore_keys': 'https://docs.fast.ai/text.learner.html#load_ignore_keys',
                                     'fastai.text.learner.load_model_text': 'https://docs.fast.ai/text.learner.html#load_model_text',
                                     'fastai.text.learner.match_embeds': 'https://docs.fast.ai/text.learner.html#match_embeds',
                                     'fastai.text.learner.plot_top_losses': 'https://docs.fast.ai/text.learner.html#plot_top_losses',
                                     'fastai.text.learner.show_results': 'https://docs.fast.ai/text.learner.html#show_results',
                                     'fastai.text.learner.text_classifier_learner': 'https://docs.fast.ai/text.learner.html#text_classifier_learner'},
            'fastai.text.models.awdlstm': { 'fastai.text.models.awdlstm.AWD_LSTM': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm',
                                            'fastai.text.models.awdlstm.AWD_LSTM.forward': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm.forward',
                                            'fastai.text.models.awdlstm.AWD_LSTM.reset': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm.reset',
                                            'fastai.text.models.awdlstm.EmbeddingDropout': 'https://docs.fast.ai/text.models.awdlstm.html#embeddingdropout',
                                            'fastai.text.models.awdlstm.EmbeddingDropout.forward': 'https://docs.fast.ai/text.models.awdlstm.html#embeddingdropout.forward',
                                            'fastai.text.models.awdlstm.RNNDropout': 'https://docs.fast.ai/text.models.awdlstm.html#rnndropout',
                                            'fastai.text.models.awdlstm.RNNDropout.forward': 'https://docs.fast.ai/text.models.awdlstm.html#rnndropout.forward',
                                            'fastai.text.models.awdlstm.WeightDropout': 'https://docs.fast.ai/text.models.awdlstm.html#weightdropout',
                                            'fastai.text.models.awdlstm.WeightDropout.forward': 'https://docs.fast.ai/text.models.awdlstm.html#weightdropout.forward',
                                            'fastai.text.models.awdlstm.WeightDropout.reset': 'https://docs.fast.ai/text.models.awdlstm.html#weightdropout.reset',
                                            'fastai.text.models.awdlstm.awd_lstm_clas_config': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm_clas_config',
                                            'fastai.text.models.awdlstm.awd_lstm_clas_split': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm_clas_split',
                                            'fastai.text.models.awdlstm.awd_lstm_lm_config': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm_lm_config',
                                            'fastai.text.models.awdlstm.awd_lstm_lm_split': 'https://docs.fast.ai/text.models.awdlstm.html#awd_lstm_lm_split',
                                            'fastai.text.models.awdlstm.dropout_mask': 'https://docs.fast.ai/text.models.awdlstm.html#dropout_mask'},
            'fastai.text.models.core': { 'fastai.text.models.core.LinearDecoder': 'https://docs.fast.ai/text.models.core.html#lineardecoder',
                                         'fastai.text.models.core.LinearDecoder.forward': 'https://docs.fast.ai/text.models.core.html#lineardecoder.forward',
                                         'fastai.text.models.core.PoolingLinearClassifier': 'https://docs.fast.ai/text.models.core.html#poolinglinearclassifier',
                                         'fastai.text.models.core.PoolingLinearClassifier.forward': 'https://docs.fast.ai/text.models.core.html#poolinglinearclassifier.forward',
                                         'fastai.text.models.core.SentenceEncoder': 'https://docs.fast.ai/text.models.core.html#sentenceencoder',
                                         'fastai.text.models.core.SentenceEncoder.forward': 'https://docs.fast.ai/text.models.core.html#sentenceencoder.forward',
                                         'fastai.text.models.core.SentenceEncoder.reset': 'https://docs.fast.ai/text.models.core.html#sentenceencoder.reset',
                                         'fastai.text.models.core.SequentialRNN': 'https://docs.fast.ai/text.models.core.html#sequentialrnn',
                                         'fastai.text.models.core.SequentialRNN.reset': 'https://docs.fast.ai/text.models.core.html#sequentialrnn.reset',
                                         'fastai.text.models.core.get_language_model': 'https://docs.fast.ai/text.models.core.html#get_language_model',
                                         'fastai.text.models.core.get_text_classifier': 'https://docs.fast.ai/text.models.core.html#get_text_classifier',
                                         'fastai.text.models.core.masked_concat_pool': 'https://docs.fast.ai/text.models.core.html#masked_concat_pool'},
            'fastai.torch_basics': {},
            'fastai.torch_core': { 'fastai.torch_core.ArrayBase': 'https://docs.fast.ai/torch_core.html#arraybase',
                                   'fastai.torch_core.ArrayImage': 'https://docs.fast.ai/torch_core.html#arrayimage',
                                   'fastai.torch_core.ArrayImageBW': 'https://docs.fast.ai/torch_core.html#arrayimagebw',
                                   'fastai.torch_core.ArrayImageBase': 'https://docs.fast.ai/torch_core.html#arrayimagebase',
                                   'fastai.torch_core.ArrayImageBase.show': 'https://docs.fast.ai/torch_core.html#arrayimagebase.show',
                                   'fastai.torch_core.ArrayMask': 'https://docs.fast.ai/torch_core.html#arraymask',
                                   'fastai.torch_core.Chunks': 'https://docs.fast.ai/torch_core.html#chunks',
                                   'fastai.torch_core.Chunks.doc_idx': 'https://docs.fast.ai/torch_core.html#chunks.doc_idx',
                                   'fastai.torch_core.Chunks.getslice': 'https://docs.fast.ai/torch_core.html#chunks.getslice',
                                   'fastai.torch_core.L.cat': 'https://docs.fast.ai/torch_core.html#l.cat',
                                   'fastai.torch_core.L.stack': 'https://docs.fast.ai/torch_core.html#l.stack',
                                   'fastai.torch_core.L.tensored': 'https://docs.fast.ai/torch_core.html#l.tensored',
                                   'fastai.torch_core.Module': 'https://docs.fast.ai/torch_core.html#module',
                                   'fastai.torch_core.Path.load_array': 'https://docs.fast.ai/torch_core.html#path.load_array',
                                   'fastai.torch_core.Path.save_array': 'https://docs.fast.ai/torch_core.html#path.save_array',
                                   'fastai.torch_core.ShowTitle': 'https://docs.fast.ai/torch_core.html#showtitle',
                                   'fastai.torch_core.ShowTitle.show': 'https://docs.fast.ai/torch_core.html#showtitle.show',
                                   'fastai.torch_core.Tensor.__array_eq__': 'https://docs.fast.ai/torch_core.html#tensor.__array_eq__',
                                   'fastai.torch_core.Tensor.as_subclass': 'https://docs.fast.ai/torch_core.html#tensor.as_subclass',
                                   'fastai.torch_core.Tensor.interp_1d': 'https://docs.fast.ai/torch_core.html#tensor.interp_1d',
                                   'fastai.torch_core.Tensor.pca': 'https://docs.fast.ai/torch_core.html#tensor.pca',
                                   'fastai.torch_core.Tensor.set_meta': 'https://docs.fast.ai/torch_core.html#tensor.set_meta',
                                   'fastai.torch_core.TensorBase': 'https://docs.fast.ai/torch_core.html#tensorbase',
                                   'fastai.torch_core.TensorBase.new': 'https://docs.fast.ai/torch_core.html#tensorbase.new',
                                   'fastai.torch_core.TensorBase.new_ones': 'https://docs.fast.ai/torch_core.html#tensorbase.new_ones',
                                   'fastai.torch_core.TensorBase.new_tensor': 'https://docs.fast.ai/torch_core.html#tensorbase.new_tensor',
                                   'fastai.torch_core.TensorBase.register_func': 'https://docs.fast.ai/torch_core.html#tensorbase.register_func',
                                   'fastai.torch_core.TensorBase.requires_grad_': 'https://docs.fast.ai/torch_core.html#tensorbase.requires_grad_',
                                   'fastai.torch_core.TensorCategory': 'https://docs.fast.ai/torch_core.html#tensorcategory',
                                   'fastai.torch_core.TensorFlowField': 'https://docs.fast.ai/torch_core.html#tensorflowfield',
                                   'fastai.torch_core.TensorImage': 'https://docs.fast.ai/torch_core.html#tensorimage',
                                   'fastai.torch_core.TensorImageBW': 'https://docs.fast.ai/torch_core.html#tensorimagebw',
                                   'fastai.torch_core.TensorImageBase': 'https://docs.fast.ai/torch_core.html#tensorimagebase',
                                   'fastai.torch_core.TensorImageBase.show': 'https://docs.fast.ai/torch_core.html#tensorimagebase.show',
                                   'fastai.torch_core.TensorMask': 'https://docs.fast.ai/torch_core.html#tensormask',
                                   'fastai.torch_core.TensorMask.show': 'https://docs.fast.ai/torch_core.html#tensormask.show',
                                   'fastai.torch_core.TensorMultiCategory': 'https://docs.fast.ai/torch_core.html#tensormulticategory',
                                   'fastai.torch_core.TitledFloat': 'https://docs.fast.ai/torch_core.html#titledfloat',
                                   'fastai.torch_core.TitledFloat.show': 'https://docs.fast.ai/torch_core.html#titledfloat.show',
                                   'fastai.torch_core.TitledInt': 'https://docs.fast.ai/torch_core.html#titledint',
                                   'fastai.torch_core.TitledInt.show': 'https://docs.fast.ai/torch_core.html#titledint.show',
                                   'fastai.torch_core.TitledStr': 'https://docs.fast.ai/torch_core.html#titledstr',
                                   'fastai.torch_core.TitledStr.show': 'https://docs.fast.ai/torch_core.html#titledstr.show',
                                   'fastai.torch_core.TitledStr.truncate': 'https://docs.fast.ai/torch_core.html#titledstr.truncate',
                                   'fastai.torch_core.TitledTensorScalar': 'https://docs.fast.ai/torch_core.html#titledtensorscalar',
                                   'fastai.torch_core.TitledTensorScalar.show': 'https://docs.fast.ai/torch_core.html#titledtensorscalar.show',
                                   'fastai.torch_core.TitledTuple': 'https://docs.fast.ai/torch_core.html#titledtuple',
                                   'fastai.torch_core.TitledTuple.show': 'https://docs.fast.ai/torch_core.html#titledtuple.show',
                                   'fastai.torch_core.apply': 'https://docs.fast.ai/torch_core.html#apply',
                                   'fastai.torch_core.apply_init': 'https://docs.fast.ai/torch_core.html#apply_init',
                                   'fastai.torch_core.apply_leaf': 'https://docs.fast.ai/torch_core.html#apply_leaf',
                                   'fastai.torch_core.base_doc': 'https://docs.fast.ai/torch_core.html#base_doc',
                                   'fastai.torch_core.batch_to_samples': 'https://docs.fast.ai/torch_core.html#batch_to_samples',
                                   'fastai.torch_core.concat': 'https://docs.fast.ai/torch_core.html#concat',
                                   'fastai.torch_core.cond_init': 'https://docs.fast.ai/torch_core.html#cond_init',
                                   'fastai.torch_core.default_device': 'https://docs.fast.ai/torch_core.html#default_device',
                                   'fastai.torch_core.display_df': 'https://docs.fast.ai/torch_core.html#display_df',
                                   'fastai.torch_core.distrib_barrier': 'https://docs.fast.ai/torch_core.html#distrib_barrier',
                                   'fastai.torch_core.doc': 'https://docs.fast.ai/torch_core.html#doc',
                                   'fastai.torch_core.find_bs': 'https://docs.fast.ai/torch_core.html#find_bs',
                                   'fastai.torch_core.find_device': 'https://docs.fast.ai/torch_core.html#find_device',
                                   'fastai.torch_core.flatten_check': 'https://docs.fast.ai/torch_core.html#flatten_check',
                                   'fastai.torch_core.get_empty_df': 'https://docs.fast.ai/torch_core.html#get_empty_df',
                                   'fastai.torch_core.get_first': 'https://docs.fast.ai/torch_core.html#get_first',
                                   'fastai.torch_core.get_model': 'https://docs.fast.ai/torch_core.html#get_model',
                                   'fastai.torch_core.get_random_states': 'https://docs.fast.ai/torch_core.html#get_random_states',
                                   'fastai.torch_core.grad_module': 'https://docs.fast.ai/torch_core.html#grad_module',
                                   'fastai.torch_core.init_default': 'https://docs.fast.ai/torch_core.html#init_default',
                                   'fastai.torch_core.ismin_torch': 'https://docs.fast.ai/torch_core.html#ismin_torch',
                                   'fastai.torch_core.item_find': 'https://docs.fast.ai/torch_core.html#item_find',
                                   'fastai.torch_core.logit': 'https://docs.fast.ai/torch_core.html#logit',
                                   'fastai.torch_core.make_cross_image': 'https://docs.fast.ai/torch_core.html#make_cross_image',
                                   'fastai.torch_core.master_bar': 'https://docs.fast.ai/torch_core.html#master_bar',
                                   'fastai.torch_core.maybe_gather': 'https://docs.fast.ai/torch_core.html#maybe_gather',
                                   'fastai.torch_core.nested_reorder': 'https://docs.fast.ai/torch_core.html#nested_reorder',
                                   'fastai.torch_core.no_random': 'https://docs.fast.ai/torch_core.html#no_random',
                                   'fastai.torch_core.norm_bias_params': 'https://docs.fast.ai/torch_core.html#norm_bias_params',
                                   'fastai.torch_core.norm_types': 'https://docs.fast.ai/torch_core.html#norm_types',
                                   'fastai.torch_core.notmax_torch': 'https://docs.fast.ai/torch_core.html#notmax_torch',
                                   'fastai.torch_core.np_func': 'https://docs.fast.ai/torch_core.html#np_func',
                                   'fastai.torch_core.num_distrib': 'https://docs.fast.ai/torch_core.html#num_distrib',
                                   'fastai.torch_core.one_hot': 'https://docs.fast.ai/torch_core.html#one_hot',
                                   'fastai.torch_core.one_hot_decode': 'https://docs.fast.ai/torch_core.html#one_hot_decode',
                                   'fastai.torch_core.one_param': 'https://docs.fast.ai/torch_core.html#one_param',
                                   'fastai.torch_core.params': 'https://docs.fast.ai/torch_core.html#params',
                                   'fastai.torch_core.pd.DataFrame.__init__': 'https://docs.fast.ai/torch_core.html#pd.dataframe.__init__',
                                   'fastai.torch_core.progress_bar': 'https://docs.fast.ai/torch_core.html#progress_bar',
                                   'fastai.torch_core.rank_distrib': 'https://docs.fast.ai/torch_core.html#rank_distrib',
                                   'fastai.torch_core.requires_grad': 'https://docs.fast.ai/torch_core.html#requires_grad',
                                   'fastai.torch_core.script_bwd': 'https://docs.fast.ai/torch_core.html#script_bwd',
                                   'fastai.torch_core.script_fwd': 'https://docs.fast.ai/torch_core.html#script_fwd',
                                   'fastai.torch_core.script_save_ctx': 'https://docs.fast.ai/torch_core.html#script_save_ctx',
                                   'fastai.torch_core.script_use_ctx': 'https://docs.fast.ai/torch_core.html#script_use_ctx',
                                   'fastai.torch_core.set_random_states': 'https://docs.fast.ai/torch_core.html#set_random_states',
                                   'fastai.torch_core.set_seed': 'https://docs.fast.ai/torch_core.html#set_seed',
                                   'fastai.torch_core.setup_cuda': 'https://docs.fast.ai/torch_core.html#setup_cuda',
                                   'fastai.torch_core.show_image': 'https://docs.fast.ai/torch_core.html#show_image',
                                   'fastai.torch_core.show_image_batch': 'https://docs.fast.ai/torch_core.html#show_image_batch',
                                   'fastai.torch_core.show_images': 'https://docs.fast.ai/torch_core.html#show_images',
                                   'fastai.torch_core.show_title': 'https://docs.fast.ai/torch_core.html#show_title',
                                   'fastai.torch_core.show_titled_image': 'https://docs.fast.ai/torch_core.html#show_titled_image',
                                   'fastai.torch_core.subplots': 'https://docs.fast.ai/torch_core.html#subplots',
                                   'fastai.torch_core.tensor': 'https://docs.fast.ai/torch_core.html#tensor',
                                   'fastai.torch_core.to_concat': 'https://docs.fast.ai/torch_core.html#to_concat',
                                   'fastai.torch_core.to_cpu': 'https://docs.fast.ai/torch_core.html#to_cpu',
                                   'fastai.torch_core.to_detach': 'https://docs.fast.ai/torch_core.html#to_detach',
                                   'fastai.torch_core.to_device': 'https://docs.fast.ai/torch_core.html#to_device',
                                   'fastai.torch_core.to_float': 'https://docs.fast.ai/torch_core.html#to_float',
                                   'fastai.torch_core.to_half': 'https://docs.fast.ai/torch_core.html#to_half',
                                   'fastai.torch_core.to_np': 'https://docs.fast.ai/torch_core.html#to_np',
                                   'fastai.torch_core.trainable_params': 'https://docs.fast.ai/torch_core.html#trainable_params',
                                   'fastai.torch_core.unsqueeze': 'https://docs.fast.ai/torch_core.html#unsqueeze',
                                   'fastai.torch_core.unsqueeze_': 'https://docs.fast.ai/torch_core.html#unsqueeze_'},
            'fastai.torch_imports': {},
            'fastai.vision.all': {},
            'fastai.vision.augment': { 'fastai.vision.augment.AffineCoordTfm': 'https://docs.fast.ai/vision.augment.html#affinecoordtfm',
                                       'fastai.vision.augment.AffineCoordTfm.before_call': 'https://docs.fast.ai/vision.augment.html#affinecoordtfm.before_call',
                                       'fastai.vision.augment.AffineCoordTfm.compose': 'https://docs.fast.ai/vision.augment.html#affinecoordtfm.compose',
                                       'fastai.vision.augment.AffineCoordTfm.encodes': 'https://docs.fast.ai/vision.augment.html#affinecoordtfm.encodes',
                                       'fastai.vision.augment.Brightness': 'https://docs.fast.ai/vision.augment.html#brightness',
                                       'fastai.vision.augment.Contrast': 'https://docs.fast.ai/vision.augment.html#contrast',
                                       'fastai.vision.augment.CropPad': 'https://docs.fast.ai/vision.augment.html#croppad',
                                       'fastai.vision.augment.CropPad.encodes': 'https://docs.fast.ai/vision.augment.html#croppad.encodes',
                                       'fastai.vision.augment.DeterministicDihedral': 'https://docs.fast.ai/vision.augment.html#deterministicdihedral',
                                       'fastai.vision.augment.DeterministicDraw': 'https://docs.fast.ai/vision.augment.html#deterministicdraw',
                                       'fastai.vision.augment.DeterministicFlip': 'https://docs.fast.ai/vision.augment.html#deterministicflip',
                                       'fastai.vision.augment.Dihedral': 'https://docs.fast.ai/vision.augment.html#dihedral',
                                       'fastai.vision.augment.DihedralItem': 'https://docs.fast.ai/vision.augment.html#dihedralitem',
                                       'fastai.vision.augment.DihedralItem.before_call': 'https://docs.fast.ai/vision.augment.html#dihedralitem.before_call',
                                       'fastai.vision.augment.DihedralItem.encodes': 'https://docs.fast.ai/vision.augment.html#dihedralitem.encodes',
                                       'fastai.vision.augment.Flip': 'https://docs.fast.ai/vision.augment.html#flip',
                                       'fastai.vision.augment.FlipItem': 'https://docs.fast.ai/vision.augment.html#flipitem',
                                       'fastai.vision.augment.FlipItem.encodes': 'https://docs.fast.ai/vision.augment.html#flipitem.encodes',
                                       'fastai.vision.augment.HSVTfm': 'https://docs.fast.ai/vision.augment.html#hsvtfm',
                                       'fastai.vision.augment.Hue': 'https://docs.fast.ai/vision.augment.html#hue',
                                       'fastai.vision.augment.Image.Image._do_crop_pad': 'https://docs.fast.ai/vision.augment.html#image.image._do_crop_pad',
                                       'fastai.vision.augment.Image.Image.crop_pad': 'https://docs.fast.ai/vision.augment.html#image.image.crop_pad',
                                       'fastai.vision.augment.Image.Image.flip_lr': 'https://docs.fast.ai/vision.augment.html#image.image.flip_lr',
                                       'fastai.vision.augment.LightingTfm': 'https://docs.fast.ai/vision.augment.html#lightingtfm',
                                       'fastai.vision.augment.OldRandomCrop': 'https://docs.fast.ai/vision.augment.html#oldrandomcrop',
                                       'fastai.vision.augment.OldRandomCrop.before_call': 'https://docs.fast.ai/vision.augment.html#oldrandomcrop.before_call',
                                       'fastai.vision.augment.PILImage.dihedral': 'https://docs.fast.ai/vision.augment.html#pilimage.dihedral',
                                       'fastai.vision.augment.PadMode': 'https://docs.fast.ai/vision.augment.html#padmode',
                                       'fastai.vision.augment.RandTransform': 'https://docs.fast.ai/vision.augment.html#randtransform',
                                       'fastai.vision.augment.RandTransform.before_call': 'https://docs.fast.ai/vision.augment.html#randtransform.before_call',
                                       'fastai.vision.augment.RandomCrop': 'https://docs.fast.ai/vision.augment.html#randomcrop',
                                       'fastai.vision.augment.RandomCrop.before_call': 'https://docs.fast.ai/vision.augment.html#randomcrop.before_call',
                                       'fastai.vision.augment.RandomCrop.encodes': 'https://docs.fast.ai/vision.augment.html#randomcrop.encodes',
                                       'fastai.vision.augment.RandomErasing': 'https://docs.fast.ai/vision.augment.html#randomerasing',
                                       'fastai.vision.augment.RandomErasing.encodes': 'https://docs.fast.ai/vision.augment.html#randomerasing.encodes',
                                       'fastai.vision.augment.RandomResizedCrop': 'https://docs.fast.ai/vision.augment.html#randomresizedcrop',
                                       'fastai.vision.augment.RandomResizedCrop.before_call': 'https://docs.fast.ai/vision.augment.html#randomresizedcrop.before_call',
                                       'fastai.vision.augment.RandomResizedCrop.encodes': 'https://docs.fast.ai/vision.augment.html#randomresizedcrop.encodes',
                                       'fastai.vision.augment.RandomResizedCropGPU': 'https://docs.fast.ai/vision.augment.html#randomresizedcropgpu',
                                       'fastai.vision.augment.RandomResizedCropGPU.before_call': 'https://docs.fast.ai/vision.augment.html#randomresizedcropgpu.before_call',
                                       'fastai.vision.augment.RandomResizedCropGPU.encodes': 'https://docs.fast.ai/vision.augment.html#randomresizedcropgpu.encodes',
                                       'fastai.vision.augment.RatioResize': 'https://docs.fast.ai/vision.augment.html#ratioresize',
                                       'fastai.vision.augment.RatioResize.encodes': 'https://docs.fast.ai/vision.augment.html#ratioresize.encodes',
                                       'fastai.vision.augment.Resize': 'https://docs.fast.ai/vision.augment.html#resize',
                                       'fastai.vision.augment.Resize.before_call': 'https://docs.fast.ai/vision.augment.html#resize.before_call',
                                       'fastai.vision.augment.Resize.encodes': 'https://docs.fast.ai/vision.augment.html#resize.encodes',
                                       'fastai.vision.augment.ResizeMethod': 'https://docs.fast.ai/vision.augment.html#resizemethod',
                                       'fastai.vision.augment.Rotate': 'https://docs.fast.ai/vision.augment.html#rotate',
                                       'fastai.vision.augment.Saturation': 'https://docs.fast.ai/vision.augment.html#saturation',
                                       'fastai.vision.augment.SpaceTfm': 'https://docs.fast.ai/vision.augment.html#spacetfm',
                                       'fastai.vision.augment.SpaceTfm.before_call': 'https://docs.fast.ai/vision.augment.html#spacetfm.before_call',
                                       'fastai.vision.augment.SpaceTfm.compose': 'https://docs.fast.ai/vision.augment.html#spacetfm.compose',
                                       'fastai.vision.augment.SpaceTfm.encodes': 'https://docs.fast.ai/vision.augment.html#spacetfm.encodes',
                                       'fastai.vision.augment.TensorBBox._do_crop_pad': 'https://docs.fast.ai/vision.augment.html#tensorbbox._do_crop_pad',
                                       'fastai.vision.augment.TensorBBox.affine_coord': 'https://docs.fast.ai/vision.augment.html#tensorbbox.affine_coord',
                                       'fastai.vision.augment.TensorBBox.crop_pad': 'https://docs.fast.ai/vision.augment.html#tensorbbox.crop_pad',
                                       'fastai.vision.augment.TensorBBox.dihedral': 'https://docs.fast.ai/vision.augment.html#tensorbbox.dihedral',
                                       'fastai.vision.augment.TensorBBox.dihedral_batch': 'https://docs.fast.ai/vision.augment.html#tensorbbox.dihedral_batch',
                                       'fastai.vision.augment.TensorBBox.flip_batch': 'https://docs.fast.ai/vision.augment.html#tensorbbox.flip_batch',
                                       'fastai.vision.augment.TensorBBox.flip_lr': 'https://docs.fast.ai/vision.augment.html#tensorbbox.flip_lr',
                                       'fastai.vision.augment.TensorBBox.rotate': 'https://docs.fast.ai/vision.augment.html#tensorbbox.rotate',
                                       'fastai.vision.augment.TensorBBox.warp': 'https://docs.fast.ai/vision.augment.html#tensorbbox.warp',
                                       'fastai.vision.augment.TensorBBox.zoom': 'https://docs.fast.ai/vision.augment.html#tensorbbox.zoom',
                                       'fastai.vision.augment.TensorImage.affine_coord': 'https://docs.fast.ai/vision.augment.html#tensorimage.affine_coord',
                                       'fastai.vision.augment.TensorImage.brightness': 'https://docs.fast.ai/vision.augment.html#tensorimage.brightness',
                                       'fastai.vision.augment.TensorImage.contrast': 'https://docs.fast.ai/vision.augment.html#tensorimage.contrast',
                                       'fastai.vision.augment.TensorImage.dihedral': 'https://docs.fast.ai/vision.augment.html#tensorimage.dihedral',
                                       'fastai.vision.augment.TensorImage.dihedral_batch': 'https://docs.fast.ai/vision.augment.html#tensorimage.dihedral_batch',
                                       'fastai.vision.augment.TensorImage.flip_batch': 'https://docs.fast.ai/vision.augment.html#tensorimage.flip_batch',
                                       'fastai.vision.augment.TensorImage.hsv': 'https://docs.fast.ai/vision.augment.html#tensorimage.hsv',
                                       'fastai.vision.augment.TensorImage.hue': 'https://docs.fast.ai/vision.augment.html#tensorimage.hue',
                                       'fastai.vision.augment.TensorImage.lighting': 'https://docs.fast.ai/vision.augment.html#tensorimage.lighting',
                                       'fastai.vision.augment.TensorImage.rotate': 'https://docs.fast.ai/vision.augment.html#tensorimage.rotate',
                                       'fastai.vision.augment.TensorImage.saturation': 'https://docs.fast.ai/vision.augment.html#tensorimage.saturation',
                                       'fastai.vision.augment.TensorImage.warp': 'https://docs.fast.ai/vision.augment.html#tensorimage.warp',
                                       'fastai.vision.augment.TensorImage.zoom': 'https://docs.fast.ai/vision.augment.html#tensorimage.zoom',
                                       'fastai.vision.augment.TensorImageBase.flip_lr': 'https://docs.fast.ai/vision.augment.html#tensorimagebase.flip_lr',
                                       'fastai.vision.augment.TensorMask.affine_coord': 'https://docs.fast.ai/vision.augment.html#tensormask.affine_coord',
                                       'fastai.vision.augment.TensorMask.dihedral_batch': 'https://docs.fast.ai/vision.augment.html#tensormask.dihedral_batch',
                                       'fastai.vision.augment.TensorMask.flip_batch': 'https://docs.fast.ai/vision.augment.html#tensormask.flip_batch',
                                       'fastai.vision.augment.TensorMask.rotate': 'https://docs.fast.ai/vision.augment.html#tensormask.rotate',
                                       'fastai.vision.augment.TensorMask.warp': 'https://docs.fast.ai/vision.augment.html#tensormask.warp',
                                       'fastai.vision.augment.TensorMask.zoom': 'https://docs.fast.ai/vision.augment.html#tensormask.zoom',
                                       'fastai.vision.augment.TensorPoint._do_crop_pad': 'https://docs.fast.ai/vision.augment.html#tensorpoint._do_crop_pad',
                                       'fastai.vision.augment.TensorPoint.affine_coord': 'https://docs.fast.ai/vision.augment.html#tensorpoint.affine_coord',
                                       'fastai.vision.augment.TensorPoint.crop_pad': 'https://docs.fast.ai/vision.augment.html#tensorpoint.crop_pad',
                                       'fastai.vision.augment.TensorPoint.dihedral': 'https://docs.fast.ai/vision.augment.html#tensorpoint.dihedral',
                                       'fastai.vision.augment.TensorPoint.dihedral_batch': 'https://docs.fast.ai/vision.augment.html#tensorpoint.dihedral_batch',
                                       'fastai.vision.augment.TensorPoint.flip_batch': 'https://docs.fast.ai/vision.augment.html#tensorpoint.flip_batch',
                                       'fastai.vision.augment.TensorPoint.flip_lr': 'https://docs.fast.ai/vision.augment.html#tensorpoint.flip_lr',
                                       'fastai.vision.augment.TensorPoint.rotate': 'https://docs.fast.ai/vision.augment.html#tensorpoint.rotate',
                                       'fastai.vision.augment.TensorPoint.warp': 'https://docs.fast.ai/vision.augment.html#tensorpoint.warp',
                                       'fastai.vision.augment.TensorPoint.zoom': 'https://docs.fast.ai/vision.augment.html#tensorpoint.zoom',
                                       'fastai.vision.augment.TensorTypes': 'https://docs.fast.ai/vision.augment.html#tensortypes',
                                       'fastai.vision.augment.Warp': 'https://docs.fast.ai/vision.augment.html#warp',
                                       'fastai.vision.augment.Zoom': 'https://docs.fast.ai/vision.augment.html#zoom',
                                       'fastai.vision.augment.affine_grid': 'https://docs.fast.ai/vision.augment.html#affine_grid',
                                       'fastai.vision.augment.affine_mat': 'https://docs.fast.ai/vision.augment.html#affine_mat',
                                       'fastai.vision.augment.apply_perspective': 'https://docs.fast.ai/vision.augment.html#apply_perspective',
                                       'fastai.vision.augment.aug_transforms': 'https://docs.fast.ai/vision.augment.html#aug_transforms',
                                       'fastai.vision.augment.cutout_gaussian': 'https://docs.fast.ai/vision.augment.html#cutout_gaussian',
                                       'fastai.vision.augment.dihedral_mat': 'https://docs.fast.ai/vision.augment.html#dihedral_mat',
                                       'fastai.vision.augment.find_coeffs': 'https://docs.fast.ai/vision.augment.html#find_coeffs',
                                       'fastai.vision.augment.flip_mat': 'https://docs.fast.ai/vision.augment.html#flip_mat',
                                       'fastai.vision.augment.grayscale': 'https://docs.fast.ai/vision.augment.html#grayscale',
                                       'fastai.vision.augment.hsv2rgb': 'https://docs.fast.ai/vision.augment.html#hsv2rgb',
                                       'fastai.vision.augment.mask_tensor': 'https://docs.fast.ai/vision.augment.html#mask_tensor',
                                       'fastai.vision.augment.norm_apply_denorm': 'https://docs.fast.ai/vision.augment.html#norm_apply_denorm',
                                       'fastai.vision.augment.rgb2hsv': 'https://docs.fast.ai/vision.augment.html#rgb2hsv',
                                       'fastai.vision.augment.rotate_mat': 'https://docs.fast.ai/vision.augment.html#rotate_mat',
                                       'fastai.vision.augment.setup_aug_tfms': 'https://docs.fast.ai/vision.augment.html#setup_aug_tfms',
                                       'fastai.vision.augment.zoom_mat': 'https://docs.fast.ai/vision.augment.html#zoom_mat'},
            'fastai.vision.core': { 'fastai.vision.core.AddMaskCodes': 'https://docs.fast.ai/vision.core.html#addmaskcodes',
                                    'fastai.vision.core.AddMaskCodes.decodes': 'https://docs.fast.ai/vision.core.html#addmaskcodes.decodes',
                                    'fastai.vision.core.BBoxLabeler': 'https://docs.fast.ai/vision.core.html#bboxlabeler',
                                    'fastai.vision.core.BBoxLabeler.decode': 'https://docs.fast.ai/vision.core.html#bboxlabeler.decode',
                                    'fastai.vision.core.BBoxLabeler.decodes': 'https://docs.fast.ai/vision.core.html#bboxlabeler.decodes',
                                    'fastai.vision.core.BBoxLabeler.setups': 'https://docs.fast.ai/vision.core.html#bboxlabeler.setups',
                                    'fastai.vision.core.BILINEAR': 'https://docs.fast.ai/vision.core.html#bilinear',
                                    'fastai.vision.core.Image': 'https://docs.fast.ai/vision.core.html#image',
                                    'fastai.vision.core.Image.Image.__repr__': 'https://docs.fast.ai/vision.core.html#image.image.__repr__',
                                    'fastai.vision.core.Image.Image.aspect': 'https://docs.fast.ai/vision.core.html#image.image.aspect',
                                    'fastai.vision.core.Image.Image.n_px': 'https://docs.fast.ai/vision.core.html#image.image.n_px',
                                    'fastai.vision.core.Image.Image.reshape': 'https://docs.fast.ai/vision.core.html#image.image.reshape',
                                    'fastai.vision.core.Image.Image.resize_max': 'https://docs.fast.ai/vision.core.html#image.image.resize_max',
                                    'fastai.vision.core.Image.Image.shape': 'https://docs.fast.ai/vision.core.html#image.image.shape',
                                    'fastai.vision.core.Image.Image.to_bytes_format': 'https://docs.fast.ai/vision.core.html#image.image.to_bytes_format',
                                    'fastai.vision.core.Image.Image.to_thumb': 'https://docs.fast.ai/vision.core.html#image.image.to_thumb',
                                    'fastai.vision.core.LabeledBBox': 'https://docs.fast.ai/vision.core.html#labeledbbox',
                                    'fastai.vision.core.LabeledBBox.show': 'https://docs.fast.ai/vision.core.html#labeledbbox.show',
                                    'fastai.vision.core.NEAREST': 'https://docs.fast.ai/vision.core.html#nearest',
                                    'fastai.vision.core.OpenMask': 'https://docs.fast.ai/vision.core.html#openmask',
                                    'fastai.vision.core.PILBase': 'https://docs.fast.ai/vision.core.html#pilbase',
                                    'fastai.vision.core.PILBase.create': 'https://docs.fast.ai/vision.core.html#pilbase.create',
                                    'fastai.vision.core.PILBase.show': 'https://docs.fast.ai/vision.core.html#pilbase.show',
                                    'fastai.vision.core.PILImage': 'https://docs.fast.ai/vision.core.html#pilimage',
                                    'fastai.vision.core.PILImageBW': 'https://docs.fast.ai/vision.core.html#pilimagebw',
                                    'fastai.vision.core.PILMask': 'https://docs.fast.ai/vision.core.html#pilmask',
                                    'fastai.vision.core.PointScaler': 'https://docs.fast.ai/vision.core.html#pointscaler',
                                    'fastai.vision.core.PointScaler.decodes': 'https://docs.fast.ai/vision.core.html#pointscaler.decodes',
                                    'fastai.vision.core.PointScaler.encodes': 'https://docs.fast.ai/vision.core.html#pointscaler.encodes',
                                    'fastai.vision.core.PointScaler.setups': 'https://docs.fast.ai/vision.core.html#pointscaler.setups',
                                    'fastai.vision.core.TensorBBox': 'https://docs.fast.ai/vision.core.html#tensorbbox',
                                    'fastai.vision.core.TensorBBox.create': 'https://docs.fast.ai/vision.core.html#tensorbbox.create',
                                    'fastai.vision.core.TensorBBox.show': 'https://docs.fast.ai/vision.core.html#tensorbbox.show',
                                    'fastai.vision.core.TensorPoint': 'https://docs.fast.ai/vision.core.html#tensorpoint',
                                    'fastai.vision.core.TensorPoint.create': 'https://docs.fast.ai/vision.core.html#tensorpoint.create',
                                    'fastai.vision.core.TensorPoint.show': 'https://docs.fast.ai/vision.core.html#tensorpoint.show',
                                    'fastai.vision.core.TensorPointCreate': 'https://docs.fast.ai/vision.core.html#tensorpointcreate',
                                    'fastai.vision.core.ToTensor': 'https://docs.fast.ai/vision.core.html#totensor',
                                    'fastai.vision.core.cifar_stats': 'https://docs.fast.ai/vision.core.html#cifar_stats',
                                    'fastai.vision.core.decodes': 'https://docs.fast.ai/vision.core.html#decodes',
                                    'fastai.vision.core.encodes': 'https://docs.fast.ai/vision.core.html#encodes',
                                    'fastai.vision.core.get_annotations': 'https://docs.fast.ai/vision.core.html#get_annotations',
                                    'fastai.vision.core.image2tensor': 'https://docs.fast.ai/vision.core.html#image2tensor',
                                    'fastai.vision.core.imagenet_stats': 'https://docs.fast.ai/vision.core.html#imagenet_stats',
                                    'fastai.vision.core.load_image': 'https://docs.fast.ai/vision.core.html#load_image',
                                    'fastai.vision.core.mnist_stats': 'https://docs.fast.ai/vision.core.html#mnist_stats',
                                    'fastai.vision.core.to_image': 'https://docs.fast.ai/vision.core.html#to_image'},
            'fastai.vision.data': { 'fastai.vision.data.BBoxBlock': 'https://docs.fast.ai/vision.data.html#bboxblock',
                                    'fastai.vision.data.BBoxLblBlock': 'https://docs.fast.ai/vision.data.html#bboxlblblock',
                                    'fastai.vision.data.ImageBlock': 'https://docs.fast.ai/vision.data.html#imageblock',
                                    'fastai.vision.data.ImageDataLoaders': 'https://docs.fast.ai/vision.data.html#imagedataloaders',
                                    'fastai.vision.data.ImageDataLoaders.from_csv': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_csv',
                                    'fastai.vision.data.ImageDataLoaders.from_df': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_df',
                                    'fastai.vision.data.ImageDataLoaders.from_folder': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_folder',
                                    'fastai.vision.data.ImageDataLoaders.from_lists': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_lists',
                                    'fastai.vision.data.ImageDataLoaders.from_name_func': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_name_func',
                                    'fastai.vision.data.ImageDataLoaders.from_name_re': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_name_re',
                                    'fastai.vision.data.ImageDataLoaders.from_path_func': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_path_func',
                                    'fastai.vision.data.ImageDataLoaders.from_path_re': 'https://docs.fast.ai/vision.data.html#imagedataloaders.from_path_re',
                                    'fastai.vision.data.MaskBlock': 'https://docs.fast.ai/vision.data.html#maskblock',
                                    'fastai.vision.data.PointBlock': 'https://docs.fast.ai/vision.data.html#pointblock',
                                    'fastai.vision.data.SegmentationDataLoaders': 'https://docs.fast.ai/vision.data.html#segmentationdataloaders',
                                    'fastai.vision.data.SegmentationDataLoaders.from_label_func': 'https://docs.fast.ai/vision.data.html#segmentationdataloaders.from_label_func',
                                    'fastai.vision.data.bb_pad': 'https://docs.fast.ai/vision.data.html#bb_pad',
                                    'fastai.vision.data.clip_remove_empty': 'https://docs.fast.ai/vision.data.html#clip_remove_empty',
                                    'fastai.vision.data.get_grid': 'https://docs.fast.ai/vision.data.html#get_grid',
                                    'fastai.vision.data.show_batch': 'https://docs.fast.ai/vision.data.html#show_batch'},
            'fastai.vision.gan': { 'fastai.vision.gan.AdaptiveGANSwitcher': 'https://docs.fast.ai/vision.gan.html#adaptiveganswitcher',
                                   'fastai.vision.gan.AdaptiveGANSwitcher.after_batch': 'https://docs.fast.ai/vision.gan.html#adaptiveganswitcher.after_batch',
                                   'fastai.vision.gan.AdaptiveLoss': 'https://docs.fast.ai/vision.gan.html#adaptiveloss',
                                   'fastai.vision.gan.AdaptiveLoss.forward': 'https://docs.fast.ai/vision.gan.html#adaptiveloss.forward',
                                   'fastai.vision.gan.AddChannels': 'https://docs.fast.ai/vision.gan.html#addchannels',
                                   'fastai.vision.gan.AddChannels.forward': 'https://docs.fast.ai/vision.gan.html#addchannels.forward',
                                   'fastai.vision.gan.DenseResBlock': 'https://docs.fast.ai/vision.gan.html#denseresblock',
                                   'fastai.vision.gan.FixedGANSwitcher': 'https://docs.fast.ai/vision.gan.html#fixedganswitcher',
                                   'fastai.vision.gan.FixedGANSwitcher.after_batch': 'https://docs.fast.ai/vision.gan.html#fixedganswitcher.after_batch',
                                   'fastai.vision.gan.FixedGANSwitcher.before_train': 'https://docs.fast.ai/vision.gan.html#fixedganswitcher.before_train',
                                   'fastai.vision.gan.GANDiscriminativeLR': 'https://docs.fast.ai/vision.gan.html#gandiscriminativelr',
                                   'fastai.vision.gan.GANDiscriminativeLR.after_batch': 'https://docs.fast.ai/vision.gan.html#gandiscriminativelr.after_batch',
                                   'fastai.vision.gan.GANDiscriminativeLR.before_batch': 'https://docs.fast.ai/vision.gan.html#gandiscriminativelr.before_batch',
                                   'fastai.vision.gan.GANLearner': 'https://docs.fast.ai/vision.gan.html#ganlearner',
                                   'fastai.vision.gan.GANLearner.from_learners': 'https://docs.fast.ai/vision.gan.html#ganlearner.from_learners',
                                   'fastai.vision.gan.GANLearner.wgan': 'https://docs.fast.ai/vision.gan.html#ganlearner.wgan',
                                   'fastai.vision.gan.GANLoss': 'https://docs.fast.ai/vision.gan.html#ganloss',
                                   'fastai.vision.gan.GANLoss.critic': 'https://docs.fast.ai/vision.gan.html#ganloss.critic',
                                   'fastai.vision.gan.GANLoss.generator': 'https://docs.fast.ai/vision.gan.html#ganloss.generator',
                                   'fastai.vision.gan.GANModule': 'https://docs.fast.ai/vision.gan.html#ganmodule',
                                   'fastai.vision.gan.GANModule.forward': 'https://docs.fast.ai/vision.gan.html#ganmodule.forward',
                                   'fastai.vision.gan.GANModule.switch': 'https://docs.fast.ai/vision.gan.html#ganmodule.switch',
                                   'fastai.vision.gan.GANTrainer': 'https://docs.fast.ai/vision.gan.html#gantrainer',
                                   'fastai.vision.gan.GANTrainer.after_batch': 'https://docs.fast.ai/vision.gan.html#gantrainer.after_batch',
                                   'fastai.vision.gan.GANTrainer.before_batch': 'https://docs.fast.ai/vision.gan.html#gantrainer.before_batch',
                                   'fastai.vision.gan.GANTrainer.before_epoch': 'https://docs.fast.ai/vision.gan.html#gantrainer.before_epoch',
                                   'fastai.vision.gan.GANTrainer.before_fit': 'https://docs.fast.ai/vision.gan.html#gantrainer.before_fit',
                                   'fastai.vision.gan.GANTrainer.before_validate': 'https://docs.fast.ai/vision.gan.html#gantrainer.before_validate',
                                   'fastai.vision.gan.GANTrainer.switch': 'https://docs.fast.ai/vision.gan.html#gantrainer.switch',
                                   'fastai.vision.gan.InvisibleTensor': 'https://docs.fast.ai/vision.gan.html#invisibletensor',
                                   'fastai.vision.gan.InvisibleTensor.show': 'https://docs.fast.ai/vision.gan.html#invisibletensor.show',
                                   'fastai.vision.gan.accuracy_thresh_expand': 'https://docs.fast.ai/vision.gan.html#accuracy_thresh_expand',
                                   'fastai.vision.gan.basic_critic': 'https://docs.fast.ai/vision.gan.html#basic_critic',
                                   'fastai.vision.gan.basic_generator': 'https://docs.fast.ai/vision.gan.html#basic_generator',
                                   'fastai.vision.gan.gan_critic': 'https://docs.fast.ai/vision.gan.html#gan_critic',
                                   'fastai.vision.gan.gan_loss_from_func': 'https://docs.fast.ai/vision.gan.html#gan_loss_from_func',
                                   'fastai.vision.gan.generate_noise': 'https://docs.fast.ai/vision.gan.html#generate_noise',
                                   'fastai.vision.gan.set_freeze_model': 'https://docs.fast.ai/vision.gan.html#set_freeze_model',
                                   'fastai.vision.gan.show_batch': 'https://docs.fast.ai/vision.gan.html#show_batch',
                                   'fastai.vision.gan.show_results': 'https://docs.fast.ai/vision.gan.html#show_results'},
            'fastai.vision.learner': { 'fastai.vision.learner.TimmBody': 'https://docs.fast.ai/vision.learner.html#timmbody',
                                       'fastai.vision.learner.TimmBody.forward': 'https://docs.fast.ai/vision.learner.html#timmbody.forward',
                                       'fastai.vision.learner.add_head': 'https://docs.fast.ai/vision.learner.html#add_head',
                                       'fastai.vision.learner.cnn_learner': 'https://docs.fast.ai/vision.learner.html#cnn_learner',
                                       'fastai.vision.learner.create_body': 'https://docs.fast.ai/vision.learner.html#create_body',
                                       'fastai.vision.learner.create_cnn_model': 'https://docs.fast.ai/vision.learner.html#create_cnn_model',
                                       'fastai.vision.learner.create_head': 'https://docs.fast.ai/vision.learner.html#create_head',
                                       'fastai.vision.learner.create_timm_model': 'https://docs.fast.ai/vision.learner.html#create_timm_model',
                                       'fastai.vision.learner.create_unet_model': 'https://docs.fast.ai/vision.learner.html#create_unet_model',
                                       'fastai.vision.learner.create_vision_model': 'https://docs.fast.ai/vision.learner.html#create_vision_model',
                                       'fastai.vision.learner.cut_model': 'https://docs.fast.ai/vision.learner.html#cut_model',
                                       'fastai.vision.learner.default_split': 'https://docs.fast.ai/vision.learner.html#default_split',
                                       'fastai.vision.learner.has_pool_type': 'https://docs.fast.ai/vision.learner.html#has_pool_type',
                                       'fastai.vision.learner.model_meta': 'https://docs.fast.ai/vision.learner.html#model_meta',
                                       'fastai.vision.learner.plot_top_losses': 'https://docs.fast.ai/vision.learner.html#plot_top_losses',
                                       'fastai.vision.learner.show_results': 'https://docs.fast.ai/vision.learner.html#show_results',
                                       'fastai.vision.learner.unet_learner': 'https://docs.fast.ai/vision.learner.html#unet_learner',
                                       'fastai.vision.learner.vision_learner': 'https://docs.fast.ai/vision.learner.html#vision_learner'},
            'fastai.vision.models.all': {},
            'fastai.vision.models.tvm': {},
            'fastai.vision.models.unet': { 'fastai.vision.models.unet.DynamicUnet': 'https://docs.fast.ai/vision.models.unet.html#dynamicunet',
                                           'fastai.vision.models.unet.ResizeToOrig': 'https://docs.fast.ai/vision.models.unet.html#resizetoorig',
                                           'fastai.vision.models.unet.ResizeToOrig.forward': 'https://docs.fast.ai/vision.models.unet.html#resizetoorig.forward',
                                           'fastai.vision.models.unet.UnetBlock': 'https://docs.fast.ai/vision.models.unet.html#unetblock',
                                           'fastai.vision.models.unet.UnetBlock.forward': 'https://docs.fast.ai/vision.models.unet.html#unetblock.forward'},
            'fastai.vision.models.xresnet': { 'fastai.vision.models.xresnet.XResNet': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet',
                                              'fastai.vision.models.xresnet.g0': 'https://docs.fast.ai/vision.models.xresnet.html#g0',
                                              'fastai.vision.models.xresnet.g1': 'https://docs.fast.ai/vision.models.xresnet.html#g1',
                                              'fastai.vision.models.xresnet.g2': 'https://docs.fast.ai/vision.models.xresnet.html#g2',
                                              'fastai.vision.models.xresnet.g3': 'https://docs.fast.ai/vision.models.xresnet.html#g3',
                                              'fastai.vision.models.xresnet.init_cnn': 'https://docs.fast.ai/vision.models.xresnet.html#init_cnn',
                                              'fastai.vision.models.xresnet.se_kwargs1': 'https://docs.fast.ai/vision.models.xresnet.html#se_kwargs1',
                                              'fastai.vision.models.xresnet.se_kwargs2': 'https://docs.fast.ai/vision.models.xresnet.html#se_kwargs2',
                                              'fastai.vision.models.xresnet.se_kwargs3': 'https://docs.fast.ai/vision.models.xresnet.html#se_kwargs3',
                                              'fastai.vision.models.xresnet.xresnet101': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet101',
                                              'fastai.vision.models.xresnet.xresnet152': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet152',
                                              'fastai.vision.models.xresnet.xresnet18': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet18',
                                              'fastai.vision.models.xresnet.xresnet18_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet18_deep',
                                              'fastai.vision.models.xresnet.xresnet18_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet18_deeper',
                                              'fastai.vision.models.xresnet.xresnet34': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet34',
                                              'fastai.vision.models.xresnet.xresnet34_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet34_deep',
                                              'fastai.vision.models.xresnet.xresnet34_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet34_deeper',
                                              'fastai.vision.models.xresnet.xresnet50': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet50',
                                              'fastai.vision.models.xresnet.xresnet50_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet50_deep',
                                              'fastai.vision.models.xresnet.xresnet50_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xresnet50_deeper',
                                              'fastai.vision.models.xresnet.xresnext101': 'https://docs.fast.ai/vision.models.xresnet.html#xresnext101',
                                              'fastai.vision.models.xresnet.xresnext18': 'https://docs.fast.ai/vision.models.xresnet.html#xresnext18',
                                              'fastai.vision.models.xresnet.xresnext34': 'https://docs.fast.ai/vision.models.xresnet.html#xresnext34',
                                              'fastai.vision.models.xresnet.xresnext50': 'https://docs.fast.ai/vision.models.xresnet.html#xresnext50',
                                              'fastai.vision.models.xresnet.xse_resnet101': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnet101',
                                              'fastai.vision.models.xresnet.xse_resnet152': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnet152',
                                              'fastai.vision.models.xresnet.xse_resnet18': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnet18',
                                              'fastai.vision.models.xresnet.xse_resnet34': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnet34',
                                              'fastai.vision.models.xresnet.xse_resnet50': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnet50',
                                              'fastai.vision.models.xresnet.xse_resnext101': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext101',
                                              'fastai.vision.models.xresnet.xse_resnext18': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext18',
                                              'fastai.vision.models.xresnet.xse_resnext18_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext18_deep',
                                              'fastai.vision.models.xresnet.xse_resnext18_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext18_deeper',
                                              'fastai.vision.models.xresnet.xse_resnext34': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext34',
                                              'fastai.vision.models.xresnet.xse_resnext34_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext34_deep',
                                              'fastai.vision.models.xresnet.xse_resnext34_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext34_deeper',
                                              'fastai.vision.models.xresnet.xse_resnext50': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext50',
                                              'fastai.vision.models.xresnet.xse_resnext50_deep': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext50_deep',
                                              'fastai.vision.models.xresnet.xse_resnext50_deeper': 'https://docs.fast.ai/vision.models.xresnet.html#xse_resnext50_deeper',
                                              'fastai.vision.models.xresnet.xsenet154': 'https://docs.fast.ai/vision.models.xresnet.html#xsenet154'},
            'fastai.vision.utils': { 'fastai.vision.utils.download_images': 'https://docs.fast.ai/vision.utils.html#download_images',
                                     'fastai.vision.utils.resize_image': 'https://docs.fast.ai/vision.utils.html#resize_image',
                                     'fastai.vision.utils.resize_images': 'https://docs.fast.ai/vision.utils.html#resize_images',
                                     'fastai.vision.utils.resize_to': 'https://docs.fast.ai/vision.utils.html#resize_to',
                                     'fastai.vision.utils.verify_image': 'https://docs.fast.ai/vision.utils.html#verify_image',
                                     'fastai.vision.utils.verify_images': 'https://docs.fast.ai/vision.utils.html#verify_images'},
            'fastai.vision.widgets': { 'fastai.vision.widgets.Box': 'https://docs.fast.ai/vision.widgets.html#box',
                                       'fastai.vision.widgets.Box.__getitem__': 'https://docs.fast.ai/vision.widgets.html#box.__getitem__',
                                       'fastai.vision.widgets.Button': 'https://docs.fast.ai/vision.widgets.html#button',
                                       'fastai.vision.widgets.Checkbox': 'https://docs.fast.ai/vision.widgets.html#checkbox',
                                       'fastai.vision.widgets.Dropdown': 'https://docs.fast.ai/vision.widgets.html#dropdown',
                                       'fastai.vision.widgets.FileUpload': 'https://docs.fast.ai/vision.widgets.html#fileupload',
                                       'fastai.vision.widgets.HBox': 'https://docs.fast.ai/vision.widgets.html#hbox',
                                       'fastai.vision.widgets.ImageClassifierCleaner': 'https://docs.fast.ai/vision.widgets.html#imageclassifiercleaner',
                                       'fastai.vision.widgets.ImageClassifierCleaner.on_change_ds': 'https://docs.fast.ai/vision.widgets.html#imageclassifiercleaner.on_change_ds',
                                       'fastai.vision.widgets.ImagesCleaner': 'https://docs.fast.ai/vision.widgets.html#imagescleaner',
                                       'fastai.vision.widgets.ImagesCleaner.change': 'https://docs.fast.ai/vision.widgets.html#imagescleaner.change',
                                       'fastai.vision.widgets.ImagesCleaner.delete': 'https://docs.fast.ai/vision.widgets.html#imagescleaner.delete',
                                       'fastai.vision.widgets.ImagesCleaner.set_fns': 'https://docs.fast.ai/vision.widgets.html#imagescleaner.set_fns',
                                       'fastai.vision.widgets.ImagesCleaner.values': 'https://docs.fast.ai/vision.widgets.html#imagescleaner.values',
                                       'fastai.vision.widgets.Label': 'https://docs.fast.ai/vision.widgets.html#label',
                                       'fastai.vision.widgets.Layout': 'https://docs.fast.ai/vision.widgets.html#layout',
                                       'fastai.vision.widgets.Output': 'https://docs.fast.ai/vision.widgets.html#output',
                                       'fastai.vision.widgets.VBox': 'https://docs.fast.ai/vision.widgets.html#vbox',
                                       'fastai.vision.widgets.carousel': 'https://docs.fast.ai/vision.widgets.html#carousel',
                                       'fastai.vision.widgets.widget': 'https://docs.fast.ai/vision.widgets.html#widget',
                                       'fastai.vision.widgets.widgets': 'https://docs.fast.ai/vision.widgets.html#widgets'}}}